<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance.transaction');

// 记录访问日志
record_log('访问收支记录页面');

// 添加/编辑收支记录处理
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加收支记录
    if ($_POST['action'] == 'add') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $trans_type = isset($_POST['trans_type']) ? intval($_POST['trans_type']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $trans_date = isset($_POST['trans_date']) ? trim($_POST['trans_date']) : '';
        $related_id = isset($_POST['related_id']) ? intval($_POST['related_id']) : null;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $operator = isset($_POST['operator']) ? trim($_POST['operator']) : '';

        if ($store_id <= 0 || $trans_type <= 0 || $amount <= 0 || empty($trans_date)) {
            $error = '请填写完整收支记录信息！';
        } else {
            try {
                // 添加收支记录
                $stmt = $pdo->prepare("INSERT INTO fin_transaction (store_id, trans_type, amount, trans_date, related_id, description, operator) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$store_id, $trans_type, $amount, $trans_date, $related_id ?: null, $description, $operator]);

                if ($result) {
                    $type_name = $trans_type <= 2 ? ($trans_type == 1 ? '销售收入' : '进货支出') : ($trans_type <= 4 ? ($trans_type == 3 ? '工资支出' : '设备维护支出') : ($trans_type == 5 ? '其他收入' : '其他支出'));
                    record_log("添加{$type_name}记录：{$amount}元 - " . ($store_id ? "门店ID:{$store_id}" : "所有门店"));
                    $success = '收支记录添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: income.php?success=add');
                    exit;
                } else {
                    $error = '收支记录添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑收支记录
    elseif ($_POST['action'] == 'edit') {
        $transaction_id = isset($_POST['transaction_id']) ? intval($_POST['transaction_id']) : 0;
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $trans_type = isset($_POST['trans_type']) ? intval($_POST['trans_type']) : 0;
        $amount = isset($_POST['amount']) ? floatval($_POST['amount']) : 0;
        $trans_date = isset($_POST['trans_date']) ? trim($_POST['trans_date']) : '';
        $related_id = isset($_POST['related_id']) ? intval($_POST['related_id']) : null;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $operator = isset($_POST['operator']) ? trim($_POST['operator']) : '';

        if ($transaction_id <= 0 || $store_id <= 0 || $trans_type <= 0 || $amount <= 0 || empty($trans_date)) {
            $error = '请填写完整收支记录信息！';
        } else {
            try {
                // 更新收支记录信息
                $stmt = $pdo->prepare("UPDATE fin_transaction SET store_id = ?, trans_type = ?, amount = ?, trans_date = ?, related_id = ?, description = ?, operator = ? WHERE id = ?");
                $result = $stmt->execute([$store_id, $trans_type, $amount, $trans_date, $related_id ?: null, $description, $operator, $transaction_id]);

                if ($result) {
                    $type_name = $trans_type <= 2 ? ($trans_type == 1 ? '销售收入' : '进货支出') : ($trans_type <= 4 ? ($trans_type == 3 ? '工资支出' : '设备维护支出') : ($trans_type == 5 ? '其他收入' : '其他支出'));
                    record_log("编辑{$type_name}记录：{$amount}元 - " . ($store_id ? "门店ID:{$store_id}" : "所有门店"));
                    $success = '收支记录更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: income.php?success=edit');
                    exit;
                } else {
                    $error = '收支记录更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除收支记录
    elseif ($_POST['action'] == 'delete') {
        $transaction_id = isset($_POST['transaction_id']) ? intval($_POST['transaction_id']) : 0;

        if ($transaction_id <= 0) {
            $error = '无效的收支记录ID！';
        } else {
            try {
                // 获取收支记录信息，用于日志记录
                $stmt = $pdo->prepare("SELECT trans_type, amount, store_id FROM fin_transaction WHERE id = ?");
                $stmt->execute([$transaction_id]);
                $transaction = $stmt->fetch();

                if (!$transaction) {
                    $error = '收支记录不存在！';
                } else {
                    // 删除收支记录
                    $stmt = $pdo->prepare("DELETE FROM fin_transaction WHERE id = ?");
                    $result = $stmt->execute([$transaction_id]);

                    if ($result) {
                        $type_name = $transaction['trans_type'] <= 2 ? ($transaction['trans_type'] == 1 ? '销售收入' : '进货支出') : ($transaction['trans_type'] <= 4 ? ($transaction['trans_type'] == 3 ? '工资支出' : '设备维护支出') : ($transaction['trans_type'] == 5 ? '其他收入' : '其他支出'));
                        record_log("删除{$type_name}记录：{$transaction['amount']}元 - 门店ID:{$transaction['store_id']}");
                        $success = '收支记录删除成功！';
                    } else {
                        $error = '收支记录删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 筛选条件处理
$filter_store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
$filter_trans_type = isset($_GET['trans_type']) ? intval($_GET['trans_type']) : 0;
$filter_start_date = isset($_GET['start_date']) ? trim($_GET['start_date']) : '';
$filter_end_date = isset($_GET['end_date']) ? trim($_GET['end_date']) : '';
$filter_keyword = isset($_GET['keyword']) ? trim($_GET['keyword']) : '';

// 获取所有门店信息，用于下拉选择
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店信息失败：' . $e->getMessage();
    $stores = [];
}

// 构建查询条件
$where = [];
$params = [];

if ($filter_store_id > 0) {
    $where[] = "t.store_id = ?";
    $params[] = $filter_store_id;
}

if ($filter_trans_type > 0) {
    $where[] = "t.trans_type = ?";
    $params[] = $filter_trans_type;
}

if (!empty($filter_start_date)) {
    $where[] = "t.trans_date >= ?";
    $params[] = $filter_start_date;
}

if (!empty($filter_end_date)) {
    $where[] = "t.trans_date <= ?";
    $params[] = $filter_end_date;
}

if (!empty($filter_keyword)) {
    $where[] = "(t.description LIKE ? OR t.operator LIKE ?)";
    $params[] = "%{$filter_keyword}%";
    $params[] = "%{$filter_keyword}%";
}

// 获取收支记录数据
try {
    $sql = "
        SELECT t.*, s.store_name 
        FROM fin_transaction t
        LEFT JOIN store_info s ON t.store_id = s.id
    ";

    if (!empty($where)) {
        $sql .= " WHERE " . implode(' AND ', $where);
    }

    $sql .= " ORDER BY t.trans_date DESC, t.id DESC";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $transactions = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取收支记录失败：' . $e->getMessage();
    $transactions = [];
}

// 计算总收入和总支出
$total_income = 0;
$total_expense = 0;
foreach ($transactions as $trans) {
    if ($trans['trans_type'] == 1 || $trans['trans_type'] == 5) { // 收入类型：销售收入，其他收入
        $total_income += $trans['amount'];
    } else { // 支出类型：进货支出，工资支出，设备维护支出，其他支出
        $total_expense += $trans['amount'];
    }
}
$net_balance = $total_income - $total_expense;

// 判断是否显示表单
$show_form = false;
$edit_transaction = null;

// 编辑收支记录时显示表单并获取信息
if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
    $show_form = true;
    $edit_id = intval($_GET['id']);
    try {
        $stmt = $pdo->prepare("SELECT * FROM fin_transaction WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_transaction = $stmt->fetch();
        if (!$edit_transaction) {
            $error = '收支记录不存在！';
            $show_form = false;
        }
    } catch (PDOException $e) {
        $error = '获取收支记录信息失败：' . $e->getMessage();
        $show_form = false;
    }
}

// 添加收支记录时显示表单
if (isset($_GET['action']) && $_GET['action'] == 'add') {
    $show_form = true;
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '收支记录添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '收支记录更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>收支记录管理</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt; 收支记录
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="income.php?action=add" class="btn btn-add">添加收支记录</a>
            </div>

            <!-- 添加/编辑收支记录表单 -->
            <?php if ($show_form): ?>
                <div class="form-container">
                    <h3><?php echo $edit_transaction ? '编辑收支记录' : '添加收支记录'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_transaction ? 'edit' : 'add'; ?>">
                        <?php if ($edit_transaction): ?>
                            <input type="hidden" name="transaction_id" value="<?php echo $edit_transaction['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="store_id">选择门店：</label>
                            <select id="store_id" name="store_id" required>
                                <option value="">请选择门店</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($edit_transaction && $edit_transaction['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="trans_type">交易类型：</label>
                            <select id="trans_type" name="trans_type" required>
                                <option value="">请选择交易类型</option>
                                <option value="1" <?php echo ($edit_transaction && $edit_transaction['trans_type'] == 1) ? 'selected' : ''; ?>>销售收入</option>
                                <option value="2" <?php echo ($edit_transaction && $edit_transaction['trans_type'] == 2) ? 'selected' : ''; ?>>进货支出</option>
                                <option value="3" <?php echo ($edit_transaction && $edit_transaction['trans_type'] == 3) ? 'selected' : ''; ?>>工资支出</option>
                                <option value="4" <?php echo ($edit_transaction && $edit_transaction['trans_type'] == 4) ? 'selected' : ''; ?>>设备维护支出</option>
                                <option value="5" <?php echo ($edit_transaction && $edit_transaction['trans_type'] == 5) ? 'selected' : ''; ?>>其他收入</option>
                                <option value="6" <?php echo ($edit_transaction && $edit_transaction['trans_type'] == 6) ? 'selected' : ''; ?>>其他支出</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="amount">金额：</label>
                            <input type="number" id="amount" name="amount" step="0.01" min="0" value="<?php echo $edit_transaction ? htmlspecialchars($edit_transaction['amount']) : '0.00'; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="trans_date">交易日期：</label>
                            <input type="date" id="trans_date" name="trans_date" value="<?php echo $edit_transaction ? htmlspecialchars($edit_transaction['trans_date']) : date('Y-m-d'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="related_id">关联ID：</label>
                            <input type="number" id="related_id" name="related_id" value="<?php echo $edit_transaction ? htmlspecialchars($edit_transaction['related_id']) : ''; ?>">
                            <small>选填，关联的订单ID、采购ID等</small>
                        </div>

                        <div class="form-group">
                            <label for="description">交易描述：</label>
                            <textarea id="description" name="description" rows="3"><?php echo $edit_transaction ? htmlspecialchars($edit_transaction['description']) : ''; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="operator">操作人：</label>
                            <input type="text" id="operator" name="operator" value="<?php echo $edit_transaction ? htmlspecialchars($edit_transaction['operator']) : ''; ?>">
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="income.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 筛选表单 -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="store_id">门店：</label>
                                <select id="store_id" name="store_id">
                                    <option value="0">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo ($filter_store_id == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="trans_type">交易类型：</label>
                                <select id="trans_type" name="trans_type">
                                    <option value="0">全部类型</option>
                                    <option value="1" <?php echo ($filter_trans_type == 1) ? 'selected' : ''; ?>>销售收入</option>
                                    <option value="2" <?php echo ($filter_trans_type == 2) ? 'selected' : ''; ?>>进货支出</option>
                                    <option value="3" <?php echo ($filter_trans_type == 3) ? 'selected' : ''; ?>>工资支出</option>
                                    <option value="4" <?php echo ($filter_trans_type == 4) ? 'selected' : ''; ?>>设备维护支出</option>
                                    <option value="5" <?php echo ($filter_trans_type == 5) ? 'selected' : ''; ?>>其他收入</option>
                                    <option value="6" <?php echo ($filter_trans_type == 6) ? 'selected' : ''; ?>>其他支出</option>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="keyword">关键字：</label>
                                <input type="text" id="keyword" name="keyword" value="<?php echo htmlspecialchars($filter_keyword); ?>" placeholder="描述或操作人">
                            </div>

                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="income.php" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <!-- 统计摘要 -->
                <div class="info-box">
                    <h3>统计摘要（<?php echo empty($filter_start_date) && empty($filter_end_date) ? '全部数据' : $filter_start_date . ' 至 ' . $filter_end_date; ?>）</h3>
                    <ul>
                        <li>总收入：￥<?php echo number_format($total_income, 2); ?></li>
                        <li>总支出：￥<?php echo number_format($total_expense, 2); ?></li>
                        <li>净收支：￥<?php echo number_format($net_balance, 2); ?>（<?php echo $net_balance >= 0 ? '盈余' : '亏损'; ?>）</li>
                    </ul>
                </div>

                <!-- 收支记录列表 -->
                <div class="table-container">
                    <h3>收支记录列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>门店</th>
                                <th>交易类型</th>
                                <th>金额</th>
                                <th>交易日期</th>
                                <th>交易描述</th>
                                <th>操作人</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($transactions)): ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无收支记录数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($transactions as $transaction): ?>
                                    <tr>
                                        <td><?php echo $transaction['id']; ?></td>
                                        <td><?php echo htmlspecialchars($transaction['store_name']); ?></td>
                                        <td>
                                            <?php
                                            $type_class = '';
                                            if ($transaction['trans_type'] == 1 || $transaction['trans_type'] == 5) {
                                                $type_class = 'status-active';
                                            } else {
                                                $type_class = 'status-inactive';
                                            }

                                            switch ($transaction['trans_type']) {
                                                case 1:
                                                    echo "<span class=\"{$type_class}\">销售收入</span>";
                                                    break;
                                                case 2:
                                                    echo "<span class=\"{$type_class}\">进货支出</span>";
                                                    break;
                                                case 3:
                                                    echo "<span class=\"{$type_class}\">工资支出</span>";
                                                    break;
                                                case 4:
                                                    echo "<span class=\"{$type_class}\">设备维护支出</span>";
                                                    break;
                                                case 5:
                                                    echo "<span class=\"{$type_class}\">其他收入</span>";
                                                    break;
                                                case 6:
                                                    echo "<span class=\"{$type_class}\">其他支出</span>";
                                                    break;
                                                default:
                                                    echo "未知类型";
                                            }
                                            ?>
                                        </td>
                                        <td>￥<?php echo number_format($transaction['amount'], 2); ?></td>
                                        <td><?php echo $transaction['trans_date']; ?></td>
                                        <td><?php echo htmlspecialchars($transaction['description'] ?: '-'); ?></td>
                                        <td><?php echo htmlspecialchars($transaction['operator'] ?: '-'); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($transaction['create_time'])); ?></td>
                                        <td>
                                            <a href="income.php?action=edit&id=<?php echo $transaction['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete">
                                                <input type="hidden" name="transaction_id" value="<?php echo $transaction['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除该收支记录吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>