<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance');

// 记录访问日志
record_log('访问财务与结算管理页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务与结算管理</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>本月销售额</h3>
                    <div class="number"><?php
                                        $currentMonth = date('Y-m');
                                        $stmt = $pdo->prepare("SELECT SUM(total_amount) as total FROM fin_daily WHERE DATE_FORMAT(sale_date, '%Y-%m') = ? AND status = 1");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo number_format($result['total'] ?: 0, 2);
                                        ?></div>
                    <div class="desc">今日销售：<?php
                                            $today = date('Y-m-d');
                                            $stmt = $pdo->prepare("SELECT total_amount FROM fin_daily WHERE sale_date = ? AND status = 1");
                                            $stmt->execute([$today]);
                                            $result = $stmt->fetch();
                                            echo number_format($result['total_amount'] ?: 0, 2);
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>订单数量</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->prepare("SELECT SUM(order_count) as total FROM fin_daily WHERE DATE_FORMAT(sale_date, '%Y-%m') = ? AND status = 1");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo $result['total'] ?: 0;
                                        ?></div>
                    <div class="desc">平均客单价：<?php
                                            $stmt = $pdo->prepare("SELECT AVG(average_amount) as avg FROM fin_daily WHERE DATE_FORMAT(sale_date, '%Y-%m') = ? AND status = 1");
                                            $stmt->execute([$currentMonth]);
                                            $result = $stmt->fetch();
                                            echo number_format($result['avg'] ?: 0, 2);
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>本月支出</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->prepare("SELECT SUM(amount) as total FROM fin_transaction WHERE trans_type IN (2,3,4,6) AND DATE_FORMAT(trans_date, '%Y-%m') = ?");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo number_format($result['total'] ?: 0, 2);
                                        ?></div>
                    <div class="desc">原料采购：<?php
                                            $stmt = $pdo->prepare("SELECT SUM(amount) as total FROM fin_transaction WHERE trans_type = 2 AND DATE_FORMAT(trans_date, '%Y-%m') = ?");
                                            $stmt->execute([$currentMonth]);
                                            $result = $stmt->fetch();
                                            echo number_format($result['total'] ?: 0, 2);
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>本月利润</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->prepare("SELECT net_profit FROM fin_profit WHERE period = ?");
                                        $stmt->execute([$currentMonth]);
                                        $result = $stmt->fetch();
                                        echo number_format($result['net_profit'] ?: 0, 2);
                                        ?></div>
                    <div class="desc">毛利率：<?php
                                            $stmt = $pdo->prepare("SELECT gross_profit_rate FROM fin_profit WHERE period = ?");
                                            $stmt->execute([$currentMonth]);
                                            $result = $stmt->fetch();
                                            echo $result['gross_profit_rate'] ? $result['gross_profit_rate'] . '%' : '0%';
                                            ?></div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="daily.php" class="function-link">
                    <h3>日销售报表</h3>
                </a>
                <a href="income.php" class="function-link">
                    <h3>收入与支出管理</h3>
                </a>
                <a href="profit.php" class="function-link">
                    <h3>利润分析</h3>
                </a>
                <a href="salary.php" class="function-link">
                    <h3>工资管理</h3>
                </a>
                <a href="bill.php" class="function-link">
                    <h3>电子账单</h3>
                </a>
            </div>

            <h2>最近销售数据</h2>
            <div class="recent-sales">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>销售日期</th>
                            <th>门店</th>
                            <th>销售额</th>
                            <th>订单数</th>
                            <th>客户数</th>
                            <th>客单价</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT d.*, s.store_name 
                                FROM fin_daily d
                                JOIN store_info s ON d.store_id = s.id
                                ORDER BY d.sale_date DESC LIMIT 7");

                        while ($row = $stmt->fetch()) {
                            $status = $row['status'] == 1 ? '正常' : '<span style="color:red">作废</span>';

                            echo "<tr>
                                <td>" . date('Y-m-d', strtotime($row['sale_date'])) . "</td>
                                <td>{$row['store_name']}</td>
                                <td>" . number_format($row['total_amount'], 2) . "</td>
                                <td>{$row['order_count']}</td>
                                <td>{$row['customer_count']}</td>
                                <td>" . number_format($row['average_amount'], 2) . "</td>
                                <td>{$status}</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='7' style='text-align:center'>暂无销售数据</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>最近交易记录</h2>
            <div class="recent-transactions">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>交易日期</th>
                            <th>门店</th>
                            <th>交易类型</th>
                            <th>金额</th>
                            <th>交易描述</th>
                            <th>操作人</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT t.*, s.store_name 
                                FROM fin_transaction t
                                JOIN store_info s ON t.store_id = s.id
                                ORDER BY t.trans_date DESC, t.id DESC LIMIT 5");

                        $transTypes = [
                            1 => '<span style="color:green">销售收入</span>',
                            2 => '<span style="color:#FF9900">进货支出</span>',
                            3 => '<span style="color:#FF9900">工资支出</span>',
                            4 => '<span style="color:#FF9900">设备维护支出</span>',
                            5 => '<span style="color:green">其他收入</span>',
                            6 => '<span style="color:#FF9900">其他支出</span>'
                        ];

                        while ($row = $stmt->fetch()) {
                            $description = $row['description'] ? $row['description'] : '-';

                            echo "<tr>
                                <td>" . date('Y-m-d', strtotime($row['trans_date'])) . "</td>
                                <td>{$row['store_name']}</td>
                                <td>{$transTypes[$row['trans_type']]}</td>
                                <td>" . number_format($row['amount'], 2) . "</td>
                                <td>{$description}</td>
                                <td>{$row['operator']}</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='6' style='text-align:center'>暂无交易记录</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>最近薪资发放</h2>
            <div class="recent-salary">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>员工ID</th>
                            <th>门店</th>
                            <th>工资月份</th>
                            <th>基本工资</th>
                            <th>提成</th>
                            <th>奖金</th>
                            <th>扣款</th>
                            <th>实发工资</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT s.*, st.store_name, e.name as emp_name  
                                FROM fin_salary s
                                JOIN store_info st ON s.store_id = st.id
                                JOIN emp_info e ON s.emp_id = e.id
                                ORDER BY s.salary_month DESC, s.id DESC LIMIT 5");

                        $salaryStatus = [
                            1 => '未发放',
                            2 => '<span style="color:green">已发放</span>'
                        ];

                        while ($row = $stmt->fetch()) {
                            echo "<tr>
                                <td>{$row['emp_name']} (ID:{$row['emp_id']})</td>
                                <td>{$row['store_name']}</td>
                                <td>{$row['salary_month']}</td>
                                <td>" . number_format($row['base_salary'], 2) . "</td>
                                <td>" . number_format($row['commission'], 2) . "</td>
                                <td>" . number_format($row['bonus'], 2) . "</td>
                                <td>" . number_format($row['deduction'], 2) . "</td>
                                <td>" . number_format($row['total_salary'], 2) . "</td>
                                <td>{$salaryStatus[$row['status']]}</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='9' style='text-align:center'>暂无薪资记录</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>