<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('member');

// 记录访问日志
record_log('访问会员与营销管理页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员与营销管理</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>会员总数</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM mem_info");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">活跃会员：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM mem_info WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>会员余额</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT SUM(balance) as total FROM mem_info");
                                        $result = $stmt->fetch();
                                        echo number_format($result['total'] ?: 0, 2);
                                        ?></div>
                    <div class="desc">累计消费：<?php
                                            $stmt = $pdo->query("SELECT SUM(total_amount) as total FROM mem_info");
                                            $result = $stmt->fetch();
                                            echo number_format($result['total'] ?: 0, 2);
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>优惠券</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM mkt_coupon WHERE member_id IS NOT NULL AND status = 1");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">可用优惠券数量</div>
                </div>

                <div class="dashboard-card">
                    <h3>营销活动</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM mkt_activity WHERE status = 1 AND NOW() BETWEEN start_time AND end_time");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">正在进行的活动</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="info.php" class="function-link">
                    <h3>会员系统</h3>
                </a>
                <a href="points.php" class="function-link">
                    <h3>积分与优惠券</h3>
                </a>
                <a href="card.php" class="function-link">
                    <h3>充值与储值卡</h3>
                </a>
                <a href="marketing.php" class="function-link">
                    <h3>营销活动</h3>
                </a>
                <a href="notify.php" class="function-link">
                    <h3>短信/微信通知</h3>
                </a>
            </div>

            <h2>会员等级分布</h2>
            <div class="member-levels">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>会员等级</th>
                            <th>会员数量</th>
                            <th>占比</th>
                            <th>累计消费</th>
                            <th>平均消费</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT level, 
                                  COUNT(*) as count, 
                                  SUM(total_amount) as total_amount
                                FROM mem_info 
                                GROUP BY level
                                ORDER BY level");

                        $totalMembers = 0;
                        $levelData = [];
                        $levelNames = [
                            1 => '普通会员',
                            2 => '银卡会员',
                            3 => '金卡会员',
                            4 => '黑卡会员'
                        ];

                        while ($row = $stmt->fetch()) {
                            $levelData[$row['level']] = $row;
                            $totalMembers += $row['count'];
                        }

                        foreach ($levelData as $level => $data) {
                            $percentage = $totalMembers > 0 ? round(($data['count'] / $totalMembers) * 100, 1) : 0;
                            $avgAmount = $data['count'] > 0 ? round($data['total_amount'] / $data['count'], 2) : 0;

                            echo "<tr>
                                <td>{$levelNames[$level]}</td>
                                <td>{$data['count']}</td>
                                <td>{$percentage}%</td>
                                <td>" . number_format($data['total_amount'], 2) . "</td>
                                <td>" . number_format($avgAmount, 2) . "</td>
                            </tr>";
                        }

                        if (count($levelData) == 0) {
                            echo "<tr><td colspan='5' style='text-align:center'>暂无会员数据</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>最近会员交易</h2>
            <div class="recent-transactions">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>会员姓名</th>
                            <th>手机号码</th>
                            <th>交易类型</th>
                            <th>交易金额/积分</th>
                            <th>订单编号</th>
                            <th>备注</th>
                            <th>交易时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT r.*, m.name, m.phone, o.order_no 
                                FROM mem_record r
                                JOIN mem_info m ON r.member_id = m.id
                                LEFT JOIN order_main o ON r.order_id = o.id
                                ORDER BY r.create_time DESC LIMIT 5");

                        $recordTypes = [
                            1 => '积分增加',
                            2 => '积分消费',
                            3 => '余额充值',
                            4 => '余额消费'
                        ];

                        while ($row = $stmt->fetch()) {
                            $orderNo = $row['order_no'] ? $row['order_no'] : '-';
                            $remark = $row['remark'] ? $row['remark'] : '-';

                            echo "<tr>
                                <td>{$row['name']}</td>
                                <td>{$row['phone']}</td>
                                <td>{$recordTypes[$row['type']]}</td>
                                <td>" . number_format($row['amount'], 2) . "</td>
                                <td>{$orderNo}</td>
                                <td>{$remark}</td>
                                <td>" . date('m-d H:i', strtotime($row['create_time'])) . "</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='7' style='text-align:center'>暂无交易记录</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>当前营销活动</h2>
            <div class="current-activities">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>活动名称</th>
                            <th>活动类型</th>
                            <th>活动规则</th>
                            <th>开始时间</th>
                            <th>结束时间</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT * FROM mkt_activity 
                                WHERE status = 1 
                                AND NOW() <= end_time 
                                ORDER BY start_time ASC LIMIT 5");

                        $activityTypes = [
                            1 => '折扣',
                            2 => '满减',
                            3 => '赠品',
                            4 => '积分翻倍'
                        ];

                        while ($row = $stmt->fetch()) {
                            $status = "未开始";
                            if (strtotime($row['start_time']) <= time() && strtotime($row['end_time']) >= time()) {
                                $status = "<span style='color:green'>进行中</span>";
                            } elseif (strtotime($row['end_time']) < time()) {
                                $status = "已结束";
                            }

                            echo "<tr>
                                <td>{$row['name']}</td>
                                <td>{$activityTypes[$row['type']]}</td>
                                <td>{$row['rule']}</td>
                                <td>" . date('Y-m-d', strtotime($row['start_time'])) . "</td>
                                <td>" . date('Y-m-d', strtotime($row['end_time'])) . "</td>
                                <td>{$status}</td>
                            </tr>";
                        }

                        if ($stmt->rowCount() == 0) {
                            echo "<tr><td colspan='6' style='text-align:center'>暂无正在进行的活动</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>