<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('member.marketing');

// 记录访问日志
record_log('访问会员营销活动页面');

// 检查并创建必要的表
try {
    // 检查分享码表是否存在，不存在则创建
    $table_exists = $pdo->query("SHOW TABLES LIKE 'mkt_share_code'")->rowCount() > 0;
    if (!$table_exists) {
        $pdo->exec("
            CREATE TABLE IF NOT EXISTS `mkt_share_code` (
              `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '分享码ID',
              `member_id` int(11) NOT NULL COMMENT '会员ID',
              `activity_id` int(11) NOT NULL COMMENT '活动ID',
              `share_code` varchar(50) NOT NULL COMMENT '分享码',
              `used_count` int(11) NOT NULL DEFAULT 0 COMMENT '使用次数',
              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              PRIMARY KEY (`id`),
              UNIQUE KEY `member_activity` (`member_id`, `activity_id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='会员分享码表';
        ");
    }
} catch (PDOException $e) {
    $error = '初始化表失败：' . $e->getMessage();
}

// 初始化变量
$view_activity_list = true;
$view_activity_stats = false;
$activities = [];

// 处理营销活动添加/编辑/删除
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加营销活动
    if ($_POST['action'] == 'add') {
        $activity_name = isset($_POST['activity_name']) ? trim($_POST['activity_name']) : '';
        $activity_type = isset($_POST['activity_type']) ? intval($_POST['activity_type']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $start_time = isset($_POST['start_time']) ? trim($_POST['start_time']) : '';
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : '';
        $discount_value = isset($_POST['discount_value']) ? floatval($_POST['discount_value']) : 0;
        $min_level = isset($_POST['min_level']) ? intval($_POST['min_level']) : 1;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if (empty($activity_name) || empty($start_time) || empty($end_time)) {
            $error = '请填写完整活动信息！';
        } else {
            try {
                // 添加营销活动
                $stmt = $pdo->prepare("INSERT INTO mkt_activity (name, type, rule, start_time, end_time, status) VALUES (?, ?, ?, ?, ?, ?)");
                $result = $stmt->execute([$activity_name, $activity_type, $description, $start_time, $end_time, $status]);

                if ($result) {
                    record_log("添加营销活动：{$activity_name}");
                    $success = '营销活动添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: marketing.php?success=add');
                    exit;
                } else {
                    $error = '营销活动添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑营销活动
    elseif ($_POST['action'] == 'edit') {
        $activity_id = isset($_POST['activity_id']) ? intval($_POST['activity_id']) : 0;
        $activity_name = isset($_POST['activity_name']) ? trim($_POST['activity_name']) : '';
        $activity_type = isset($_POST['activity_type']) ? intval($_POST['activity_type']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';
        $start_time = isset($_POST['start_time']) ? trim($_POST['start_time']) : '';
        $end_time = isset($_POST['end_time']) ? trim($_POST['end_time']) : '';
        $discount_value = isset($_POST['discount_value']) ? floatval($_POST['discount_value']) : 0;
        $min_level = isset($_POST['min_level']) ? intval($_POST['min_level']) : 1;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($activity_id <= 0 || empty($activity_name) || empty($start_time) || empty($end_time)) {
            $error = '请填写完整活动信息！';
        } else {
            try {
                // 更新营销活动
                $stmt = $pdo->prepare("UPDATE mkt_activity SET name = ?, type = ?, rule = ?, start_time = ?, end_time = ?, status = ? WHERE id = ?");
                $result = $stmt->execute([$activity_name, $activity_type, $description, $start_time, $end_time, $status, $activity_id]);

                if ($result) {
                    record_log("编辑营销活动：{$activity_name}");
                    $success = '营销活动更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: marketing.php?success=edit');
                    exit;
                } else {
                    $error = '营销活动更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除营销活动
    elseif ($_POST['action'] == 'delete') {
        $activity_id = isset($_POST['activity_id']) ? intval($_POST['activity_id']) : 0;

        if ($activity_id <= 0) {
            $error = '无效的活动ID！';
        } else {
            try {
                // 获取活动名称，用于日志记录
                $stmt = $pdo->prepare("SELECT name FROM mkt_activity WHERE id = ?");
                $stmt->execute([$activity_id]);
                $activity = $stmt->fetch();

                if (!$activity) {
                    $error = '活动不存在！';
                } else {
                    // 删除活动
                    $stmt = $pdo->prepare("DELETE FROM mkt_activity WHERE id = ?");
                    $result = $stmt->execute([$activity_id]);

                    if ($result) {
                        record_log("删除营销活动：{$activity['name']}");
                        $success = '营销活动删除成功！';
                    } else {
                        $error = '营销活动删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 生成分享码
    elseif ($_POST['action'] == 'generate_share_code') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $activity_id = isset($_POST['activity_id']) ? intval($_POST['activity_id']) : 0;

        if ($member_id <= 0 || $activity_id <= 0) {
            $error = '请选择会员和活动！';
        } else {
            try {
                // 检查会员是否存在
                $stmt = $pdo->prepare("SELECT * FROM mem_info WHERE id = ?");
                $stmt->execute([$member_id]);
                $member = $stmt->fetch();

                if (!$member) {
                    $error = '会员不存在！';
                } else {
                    // 检查活动是否存在且有效
                    $stmt = $pdo->prepare("SELECT * FROM mkt_activity WHERE id = ? AND status = 1 AND NOW() BETWEEN start_time AND end_time");
                    $stmt->execute([$activity_id]);
                    $activity = $stmt->fetch();

                    if (!$activity) {
                        $error = '活动不存在或已过期！';
                    } else {
                        // 生成分享码（组合会员ID和活动ID加随机字符串）
                        $share_code = 'S' . $member_id . 'A' . $activity_id . substr(md5(uniqid()), 0, 6);

                        // 检查是否已经有该会员的该活动的分享码
                        $stmt = $pdo->prepare("SELECT * FROM mkt_share_code WHERE member_id = ? AND activity_id = ?");
                        $stmt->execute([$member_id, $activity_id]);
                        $existing_code = $stmt->fetch();

                        if ($existing_code) {
                            // 更新已有分享码
                            $stmt = $pdo->prepare("UPDATE mkt_share_code SET share_code = ?, create_time = NOW() WHERE id = ?");
                            $result = $stmt->execute([$share_code, $existing_code['id']]);
                        } else {
                            // 添加分享码
                            $stmt = $pdo->prepare("INSERT INTO mkt_share_code (member_id, activity_id, share_code, create_time) VALUES (?, ?, ?, NOW())");
                            $result = $stmt->execute([$member_id, $activity_id, $share_code]);
                        }

                        if ($result) {
                            record_log("生成分享码：会员ID={$member_id}, 活动ID={$activity_id}, 分享码={$share_code}");
                            $success = '分享码生成成功！分享码：' . $share_code;
                        } else {
                            $error = '分享码生成失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 使用分享码
    elseif ($_POST['action'] == 'use_share_code') {
        $share_code = isset($_POST['share_code']) ? trim($_POST['share_code']) : '';
        $new_member_id = isset($_POST['new_member_id']) ? intval($_POST['new_member_id']) : 0;

        if (empty($share_code) || $new_member_id <= 0) {
            $error = '请输入分享码并选择会员！';
        } else {
            try {
                // 检查分享码是否存在
                $stmt = $pdo->prepare("
                    SELECT s.*, a.name as activity_name, a.type as activity_type, a.rule as rule
                    FROM mkt_share_code s
                    JOIN mkt_activity a ON s.activity_id = a.id
                    WHERE s.share_code = ? AND a.status = 1 AND NOW() BETWEEN a.start_time AND a.end_time
                ");
                $stmt->execute([$share_code]);
                $share_info = $stmt->fetch();

                if (!$share_info) {
                    $error = '分享码不存在或已过期！';
                } else if ($share_info['member_id'] == $new_member_id) {
                    $error = '不能使用自己的分享码！';
                } else {
                    // 检查新会员是否符合条件（例如是否是新注册会员）
                    $stmt = $pdo->prepare("SELECT * FROM mem_info WHERE id = ?");
                    $stmt->execute([$new_member_id]);
                    $new_member = $stmt->fetch();

                    if (!$new_member) {
                        $error = '会员不存在！';
                    } else {
                        // 开始事务
                        $pdo->beginTransaction();

                        // 更新分享码使用次数
                        $stmt = $pdo->prepare("UPDATE mkt_share_code SET used_count = used_count + 1 WHERE id = ?");
                        $stmt->execute([$share_info['id']]);

                        // 根据活动类型进行不同处理
                        if ($share_info['activity_type'] == 1) { // 假设类型1为赠送优惠券
                            // 生成优惠券
                            $coupon_name = '通过分享码 ' . $share_code . ' 获得的优惠券';
                            // 设置一个默认折扣值，例如 9 折
                            $discount_value = 0.90;
                            $stmt = $pdo->prepare("
                                INSERT INTO mkt_coupon (
                                    member_id, coupon_name, coupon_type, value, min_amount, 
                                    start_time, end_time, status, create_time
                                ) VALUES (
                                    ?, ?, 1, ?, 0, CURDATE(), DATE_ADD(CURDATE(), INTERVAL 30 DAY), 1, NOW()
                                )
                            ");
                            $stmt->execute([
                                $new_member_id,
                                $coupon_name,
                                $discount_value
                            ]);

                            $success_message = '分享码使用成功！已为会员生成优惠券';
                        } elseif ($share_info['activity_type'] == 2) { // 假设类型2为赠送积分
                            // 赠送积分
                            $points = intval($share_info['discount_value']);
                            $stmt = $pdo->prepare("
                                INSERT INTO mem_record (member_id, type, amount, related_id, remark, create_time) 
                                VALUES (?, 1, ?, ?, CONCAT('通过分享码 ', ?, ' 获得的积分奖励'), NOW())
                            ");
                            $stmt->execute([$new_member_id, $points, $share_info['activity_id'], $share_code]);

                            // 更新会员积分
                            $stmt = $pdo->prepare("UPDATE mem_info SET points = points + ? WHERE id = ?");
                            $stmt->execute([$points, $new_member_id]);

                            $success_message = '分享码使用成功！已为会员赠送' . $points . '积分';
                        } else {
                            throw new Exception('不支持的活动类型');
                        }

                        // 提交事务
                        $pdo->commit();

                        record_log("使用分享码：{$share_code}，会员ID={$new_member_id}");
                        $success = $success_message;
                    }
                }
            } catch (Exception $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 显示活动统计页面
if (isset($_GET['view']) && $_GET['view'] == 'stats') {
    $view_activity_list = false;
    $view_activity_stats = true;

    // 设置筛选条件
    $filter_activity_id = isset($_GET['activity_id']) ? intval($_GET['activity_id']) : 0;
    $filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
    $filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

    // 获取所有活动（用于筛选）
    try {
        $stmt = $pdo->query("SELECT id, name as activity_name FROM mkt_activity ORDER BY id DESC");
        $all_activities = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取活动列表失败：' . $e->getMessage();
        $all_activities = [];
    }

    // 获取活动统计数据
    try {
        // 查询活动参与情况
        $where = [];
        $params = [];

        if ($filter_activity_id > 0) {
            $where[] = "sc.activity_id = ?";
            $params[] = $filter_activity_id;
        }

        if (!empty($filter_start_date)) {
            $where[] = "DATE(sc.create_time) >= ?";
            $params[] = $filter_start_date;
        }

        if (!empty($filter_end_date)) {
            $where[] = "DATE(sc.create_time) <= ?";
            $params[] = $filter_end_date;
        }

        $where_clause = !empty($where) ? " WHERE " . implode(" AND ", $where) : "";

        // 如果表存在才查询
        $table_exists = $pdo->query("SHOW TABLES LIKE 'mkt_share_code'")->rowCount() > 0;

        if ($table_exists) {
            $sql = "
                SELECT sc.*, a.name as activity_name, m.name as member_name, m.phone
                FROM mkt_share_code sc
                JOIN mkt_activity a ON sc.activity_id = a.id
                JOIN mem_info m ON sc.member_id = m.id
                $where_clause
                ORDER BY sc.create_time DESC
                LIMIT 200
            ";

            $stmt = $pdo->prepare($sql);
            $stmt->execute($params);
            $share_statistics = $stmt->fetchAll();
        } else {
            $share_statistics = [];
        }
    } catch (PDOException $e) {
        $error = '获取活动统计失败：' . $e->getMessage();
        $share_statistics = [];
    }
}
// 默认显示活动列表
else {
    $view_activity_list = true;
    $view_activity_stats = false;

    // 获取所有营销活动
    try {
        // 使用别名来匹配代码中期望的字段名
        $stmt = $pdo->query("
            SELECT 
                id, 
                name as activity_name, 
                type as activity_type, 
                rule as description, 
                start_time, 
                end_time, 
                status,
                0 as discount_value,
                1 as min_level
            FROM mkt_activity 
            ORDER BY id DESC
        ");
        $activities = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取营销活动列表失败：' . $e->getMessage();
        $activities = [];
    }

    // 获取所有会员（用于分享码生成）
    try {
        $stmt = $pdo->query("SELECT id, member_no, name, phone FROM mem_info WHERE status = 1 ORDER BY id DESC");
        $members = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取会员列表失败：' . $e->getMessage();
        $members = [];
    }

    // 判断是否显示表单
    $show_form = false;
    $edit_activity = null;

    // 编辑活动时显示表单并获取活动信息
    if (isset($_GET['action']) && $_GET['action'] == 'edit' && isset($_GET['id'])) {
        $show_form = true;
        $edit_id = intval($_GET['id']);
        try {
            $stmt = $pdo->prepare("SELECT * FROM mkt_activity WHERE id = ?");
            $stmt->execute([$edit_id]);
            $edit_activity = $stmt->fetch();
            if (!$edit_activity) {
                $error = '活动不存在！';
                $show_form = false;
            }
        } catch (PDOException $e) {
            $error = '获取活动信息失败：' . $e->getMessage();
            $show_form = false;
        }
    }

    // 添加活动时显示表单
    if (isset($_GET['action']) && $_GET['action'] == 'add') {
        $show_form = true;
    }

    // 生成或使用分享码时显示表单
    $show_share_form = false;
    if (isset($_GET['action']) && ($_GET['action'] == 'share' || $_GET['action'] == 'use_share')) {
        $show_share_form = true;
    }
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add') {
        $success = '营销活动添加成功！';
    } elseif ($_GET['success'] == 'edit') {
        $success = '营销活动更新成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员营销活动</h2>
            <div class="breadcrumb">
                <a href="index.php">会员营销</a> &gt; 营销活动
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="marketing.php" class="btn <?php echo $view_activity_list && !$show_form && !$show_share_form ? 'btn-primary' : 'btn-secondary'; ?>">活动列表</a>
                <a href="marketing.php?view=stats" class="btn <?php echo $view_activity_stats ? 'btn-primary' : 'btn-secondary'; ?>">活动数据统计</a>
                <a href="marketing.php?action=add" class="btn <?php echo $show_form ? 'btn-primary' : 'btn-secondary'; ?>">添加活动</a>
                <a href="marketing.php?action=share" class="btn <?php echo $show_share_form && isset($_GET['action']) && $_GET['action'] == 'share' ? 'btn-primary' : 'btn-secondary'; ?>">生成分享码</a>
                <a href="marketing.php?action=use_share" class="btn <?php echo $show_share_form && isset($_GET['action']) && $_GET['action'] == 'use_share' ? 'btn-primary' : 'btn-secondary'; ?>">使用分享码</a>
            </div>

            <?php if ($view_activity_stats): ?>
                <!-- 活动数据统计视图 -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <input type="hidden" name="view" value="stats">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="activity_id">活动：</label>
                                <select id="activity_id" name="activity_id">
                                    <option value="0">全部</option>
                                    <?php foreach ($all_activities as $act): ?>
                                        <option value="<?php echo $act['id']; ?>" <?php echo ($filter_activity_id == $act['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($act['activity_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>

                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="marketing.php?view=stats" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <h3>分享活动参与情况（最近200条）</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>分享会员</th>
                                <th>活动名称</th>
                                <th>分享码</th>
                                <th>使用次数</th>
                                <th>创建时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($share_statistics)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无分享数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($share_statistics as $stat): ?>
                                    <tr>
                                        <td><?php echo $stat['id']; ?></td>
                                        <td><?php echo htmlspecialchars($stat['member_name'] ?: $stat['phone']); ?></td>
                                        <td><?php echo htmlspecialchars($stat['activity_name']); ?></td>
                                        <td><?php echo htmlspecialchars($stat['share_code']); ?></td>
                                        <td><?php echo $stat['used_count']; ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($stat['create_time'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php elseif ($show_form): ?>
                <!-- 添加/编辑活动表单 -->
                <div class="form-container">
                    <h3><?php echo $edit_activity ? '编辑营销活动' : '添加营销活动'; ?></h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="<?php echo $edit_activity ? 'edit' : 'add'; ?>">
                        <?php if ($edit_activity): ?>
                            <input type="hidden" name="activity_id" value="<?php echo $edit_activity['id']; ?>">
                        <?php endif; ?>

                        <div class="form-group">
                            <label for="activity_name">活动名称：</label>
                            <input type="text" id="activity_name" name="activity_name" value="<?php echo $edit_activity ? htmlspecialchars($edit_activity['activity_name']) : ''; ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="activity_type">活动类型：</label>
                            <select id="activity_type" name="activity_type">
                                <option value="1" <?php echo ($edit_activity && $edit_activity['activity_type'] == 1) ? 'selected' : ''; ?>>节假日促销</option>
                                <option value="2" <?php echo ($edit_activity && $edit_activity['activity_type'] == 2) ? 'selected' : ''; ?>>限时折扣</option>
                                <option value="3" <?php echo ($edit_activity && $edit_activity['activity_type'] == 3) ? 'selected' : ''; ?>>会员专属</option>
                                <option value="4" <?php echo ($edit_activity && $edit_activity['activity_type'] == 4) ? 'selected' : ''; ?>>分享优惠</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="description">活动描述：</label>
                            <textarea id="description" name="description" rows="3"><?php echo $edit_activity ? htmlspecialchars($edit_activity['description']) : ''; ?></textarea>
                        </div>

                        <div class="form-group">
                            <label for="start_time">开始时间：</label>
                            <input type="datetime-local" id="start_time" name="start_time" value="<?php echo $edit_activity ? date('Y-m-d\TH:i', strtotime($edit_activity['start_time'])) : date('Y-m-d\TH:i'); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="end_time">结束时间：</label>
                            <input type="datetime-local" id="end_time" name="end_time" value="<?php echo $edit_activity ? date('Y-m-d\TH:i', strtotime($edit_activity['end_time'])) : date('Y-m-d\TH:i', strtotime('+30 days')); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="discount_value">优惠值：</label>
                            <input type="number" id="discount_value" name="discount_value" min="0" step="0.01" value="<?php echo $edit_activity ? number_format($edit_activity['discount_value'], 2, '.', '') : '0.00'; ?>">
                            <small>折扣类型为折扣率时，输入0.8表示8折；为固定金额时，输入直接表示优惠金额；为积分时，输入积分值</small>
                        </div>

                        <div class="form-group">
                            <label for="min_level">最低会员等级：</label>
                            <select id="min_level" name="min_level">
                                <option value="1" <?php echo ($edit_activity && $edit_activity['min_level'] == 1) ? 'selected' : ''; ?>>普通会员</option>
                                <option value="2" <?php echo ($edit_activity && $edit_activity['min_level'] == 2) ? 'selected' : ''; ?>>银卡会员</option>
                                <option value="3" <?php echo ($edit_activity && $edit_activity['min_level'] == 3) ? 'selected' : ''; ?>>金卡会员</option>
                                <option value="4" <?php echo ($edit_activity && $edit_activity['min_level'] == 4) ? 'selected' : ''; ?>>黑卡会员</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($edit_activity && $edit_activity['status'] == 1) ? 'selected' : ''; ?>>启用</option>
                                <option value="0" <?php echo ($edit_activity && $edit_activity['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存</button>
                            <a href="marketing.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_share_form && $_GET['action'] == 'share'): ?>
                <!-- 生成分享码表单 -->
                <div class="form-container">
                    <h3>生成活动分享码</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="generate_share_code">

                        <div class="form-group">
                            <label for="member_id">选择会员：</label>
                            <select id="member_id" name="member_id" required>
                                <option value="">请选择会员</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>">
                                        <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?>
                                        (<?php echo htmlspecialchars($member['member_no']); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="activity_id">选择活动：</label>
                            <select id="activity_id" name="activity_id" required>
                                <option value="">请选择活动</option>
                                <?php
                                // 只显示有效且属于分享类型的活动
                                foreach ($activities as $activity):
                                    if ($activity['status'] == 1 && strtotime($activity['end_time']) > time()):
                                ?>
                                        <option value="<?php echo $activity['id']; ?>">
                                            <?php echo htmlspecialchars($activity['activity_name']); ?>
                                            (<?php echo date('Y-m-d', strtotime($activity['start_time'])); ?> 至
                                            <?php echo date('Y-m-d', strtotime($activity['end_time'])); ?>)
                                        </option>
                                <?php
                                    endif;
                                endforeach;
                                ?>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">生成分享码</button>
                            <a href="marketing.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php elseif ($show_share_form && $_GET['action'] == 'use_share'): ?>
                <!-- 使用分享码表单 -->
                <div class="form-container">
                    <h3>使用活动分享码</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="use_share_code">

                        <div class="form-group">
                            <label for="new_member_id">会员：</label>
                            <select id="new_member_id" name="new_member_id" required>
                                <option value="">请选择要使用分享码的会员</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>">
                                        <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?>
                                        (<?php echo htmlspecialchars($member['member_no']); ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="share_code">分享码：</label>
                            <input type="text" id="share_code" name="share_code" required>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">使用分享码</button>
                            <a href="marketing.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <!-- 活动列表视图 -->
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>活动名称</th>
                                <th>活动类型</th>
                                <th>开始时间</th>
                                <th>结束时间</th>
                                <th>优惠值</th>
                                <th>最低会员等级</th>
                                <th>状态</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($activities)): ?>
                                <tr>
                                    <td colspan="9" class="text-center">暂无活动数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($activities as $activity): ?>
                                    <tr>
                                        <td><?php echo $activity['id']; ?></td>
                                        <td><?php echo htmlspecialchars($activity['activity_name']); ?></td>
                                        <td><?php echo htmlspecialchars($activity['activity_type'] == 1 ? '节假日促销' : ($activity['activity_type'] == 2 ? '限时折扣' : ($activity['activity_type'] == 3 ? '会员专属' : '分享优惠'))); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($activity['start_time'])); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($activity['end_time'])); ?></td>
                                        <td><?php echo number_format($activity['discount_value'], 2, '.', ''); ?></td>
                                        <td><?php echo htmlspecialchars($activity['min_level'] == 1 ? '普通会员' : ($activity['min_level'] == 2 ? '银卡会员' : ($activity['min_level'] == 3 ? '金卡会员' : '黑卡会员'))); ?></td>
                                        <td><?php echo htmlspecialchars($activity['status'] == 1 ? '启用' : '禁用'); ?></td>
                                        <td>
                                            <a href="marketing.php?action=edit&id=<?php echo $activity['id']; ?>" class="btn btn-primary">编辑</a>
                                            <a href="marketing.php?action=delete&id=<?php echo $activity['id']; ?>" class="btn btn-danger" onclick="return confirm('确定要删除此活动吗？');">删除</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>