<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('member.points');

// 记录访问日志
record_log('访问会员积分管理页面');

// 初始化变量
$view_point_rules = false;
$point_rules = [];
$view_point_records = false;
$point_records = [];

// 处理积分规则添加/编辑
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加积分兑换规则
    if ($_POST['action'] == 'add_rule') {
        $rule_name = isset($_POST['rule_name']) ? trim($_POST['rule_name']) : '';
        $points_required = isset($_POST['points_required']) ? intval($_POST['points_required']) : 0;
        $reward_type = isset($_POST['reward_type']) ? intval($_POST['reward_type']) : 1;
        $reward_value = isset($_POST['reward_value']) ? floatval($_POST['reward_value']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';

        if (empty($rule_name) || $points_required <= 0 || $reward_value <= 0) {
            $error = '请填写完整规则信息！';
        } else {
            try {
                // 添加兑换规则
                $stmt = $pdo->prepare("INSERT INTO mkt_point_rule (rule_name, points_required, reward_type, reward_value, status, description, create_time) VALUES (?, ?, ?, ?, ?, ?, NOW())");
                $result = $stmt->execute([$rule_name, $points_required, $reward_type, $reward_value, $status, $description]);

                if ($result) {
                    record_log("添加积分兑换规则：{$rule_name}");
                    $success = '积分兑换规则添加成功！';
                    // 重定向到没有参数的页面
                    header('Location: points.php?success=add_rule');
                    exit;
                } else {
                    $error = '积分兑换规则添加失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 编辑积分兑换规则
    elseif ($_POST['action'] == 'edit_rule') {
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;
        $rule_name = isset($_POST['rule_name']) ? trim($_POST['rule_name']) : '';
        $points_required = isset($_POST['points_required']) ? intval($_POST['points_required']) : 0;
        $reward_type = isset($_POST['reward_type']) ? intval($_POST['reward_type']) : 1;
        $reward_value = isset($_POST['reward_value']) ? floatval($_POST['reward_value']) : 0;
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;
        $description = isset($_POST['description']) ? trim($_POST['description']) : '';

        if ($rule_id <= 0 || empty($rule_name) || $points_required <= 0 || $reward_value <= 0) {
            $error = '请填写完整规则信息！';
        } else {
            try {
                // 更新兑换规则
                $stmt = $pdo->prepare("UPDATE mkt_point_rule SET rule_name = ?, points_required = ?, reward_type = ?, reward_value = ?, status = ?, description = ? WHERE id = ?");
                $result = $stmt->execute([$rule_name, $points_required, $reward_type, $reward_value, $status, $description, $rule_id]);

                if ($result) {
                    record_log("编辑积分兑换规则：{$rule_name}");
                    $success = '积分兑换规则更新成功！';
                    // 重定向到没有参数的页面
                    header('Location: points.php?success=edit_rule');
                    exit;
                } else {
                    $error = '积分兑换规则更新失败！';
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 删除积分兑换规则
    elseif ($_POST['action'] == 'delete_rule') {
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;

        if ($rule_id <= 0) {
            $error = '无效的规则ID！';
        } else {
            try {
                // 获取规则名称，用于日志记录
                $stmt = $pdo->prepare("SELECT rule_name FROM mkt_point_rule WHERE id = ?");
                $stmt->execute([$rule_id]);
                $rule = $stmt->fetch();

                if (!$rule) {
                    $error = '规则不存在！';
                } else {
                    // 删除规则
                    $stmt = $pdo->prepare("DELETE FROM mkt_point_rule WHERE id = ?");
                    $result = $stmt->execute([$rule_id]);

                    if ($result) {
                        record_log("删除积分兑换规则：{$rule['rule_name']}");
                        $success = '积分兑换规则删除成功！';
                    } else {
                        $error = '积分兑换规则删除失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }

    // 积分兑换
    elseif ($_POST['action'] == 'exchange_points') {
        $member_id = isset($_POST['member_id']) ? intval($_POST['member_id']) : 0;
        $rule_id = isset($_POST['rule_id']) ? intval($_POST['rule_id']) : 0;
        $remark = isset($_POST['remark']) ? trim($_POST['remark']) : '';

        if ($member_id <= 0 || $rule_id <= 0) {
            $error = '请选择会员和兑换规则！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 获取会员信息
                $stmt = $pdo->prepare("SELECT * FROM mem_info WHERE id = ?");
                $stmt->execute([$member_id]);
                $member = $stmt->fetch();

                if (!$member) {
                    throw new Exception('会员不存在！');
                }

                // 获取规则信息
                $stmt = $pdo->prepare("SELECT * FROM mkt_point_rule WHERE id = ? AND status = 1");
                $stmt->execute([$rule_id]);
                $rule = $stmt->fetch();

                if (!$rule) {
                    throw new Exception('兑换规则不存在或已禁用！');
                }

                // 检查会员积分是否足够
                if ($member['points'] < $rule['points_required']) {
                    throw new Exception('会员积分不足，无法兑换！');
                }

                // 添加积分消费记录
                $stmt = $pdo->prepare("INSERT INTO mem_record (member_id, type, amount, remark, create_time) VALUES (?, 2, ?, ?, NOW())");
                $result = $stmt->execute([$member_id, $rule['points_required'], '积分兑换: ' . $rule['rule_name'] . ($remark ? ' - ' . $remark : '')]);

                if ($result) {
                    // 更新会员积分
                    $stmt = $pdo->prepare("UPDATE mem_info SET points = points - ? WHERE id = ?");
                    $stmt->execute([$rule['points_required'], $member_id]);

                    // 如果是优惠券类型的奖励，则生成优惠券
                    if ($rule['reward_type'] == 2) {
                        $coupon_name = '积分兑换-' . $rule['rule_name'];
                        $coupon_type = ($rule['reward_value'] <= 1) ? 1 : 2; // 1=折扣券，2=满减券
                        $min_amount = 0;
                        $start_time = date('Y-m-d H:i:s');
                        $end_time = date('Y-m-d H:i:s', strtotime('+30 days'));

                        $stmt = $pdo->prepare("INSERT INTO mkt_coupon (coupon_name, coupon_type, value, min_amount, member_id, status, start_time, end_time) VALUES (?, ?, ?, ?, ?, 1, ?, ?)");
                        $stmt->execute([$coupon_name, $coupon_type, $rule['reward_value'], $min_amount, $member_id, $start_time, $end_time]);
                    }

                    // 提交事务
                    $pdo->commit();

                    record_log("会员积分兑换：会员ID={$member_id}, 规则ID={$rule_id}, 积分数={$rule['points_required']}");
                    $success = '积分兑换成功！';

                    // 重定向到没有参数的页面
                    header('Location: points.php?success=exchange');
                    exit;
                } else {
                    throw new Exception('积分兑换失败！');
                }
            } catch (Exception $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = $e->getMessage();
            }
        }
    }
}

// 显示积分规则设置页面
if (isset($_GET['view']) && $_GET['view'] == 'rules') {
    $view_point_rules = true;

    // 获取所有积分兑换规则
    try {
        // 如果表不存在，则创建表
        $pdo->exec("
            CREATE TABLE IF NOT EXISTS `mkt_point_rule` (
              `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '规则ID',
              `rule_name` varchar(100) NOT NULL COMMENT '规则名称',
              `points_required` int(11) NOT NULL COMMENT '所需积分',
              `reward_type` tinyint(1) NOT NULL COMMENT '奖励类型：1=商品折扣，2=优惠券',
              `reward_value` decimal(10,2) NOT NULL COMMENT '奖励值',
              `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=启用，0=禁用',
              `description` varchar(255) DEFAULT NULL COMMENT '规则描述',
              `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
              PRIMARY KEY (`id`)
            ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='积分兑换规则表';
        ");

        $stmt = $pdo->query("SELECT * FROM mkt_point_rule ORDER BY id DESC");
        $point_rules = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取积分兑换规则失败：' . $e->getMessage();
        $point_rules = [];
    }

    // 判断是否显示编辑表单
    $show_rule_form = false;
    $edit_rule = null;

    if (isset($_GET['action']) && $_GET['action'] == 'edit_rule' && isset($_GET['id'])) {
        $show_rule_form = true;
        $edit_id = intval($_GET['id']);
        try {
            $stmt = $pdo->prepare("SELECT * FROM mkt_point_rule WHERE id = ?");
            $stmt->execute([$edit_id]);
            $edit_rule = $stmt->fetch();
            if (!$edit_rule) {
                $error = '积分兑换规则不存在！';
                $show_rule_form = false;
            }
        } catch (PDOException $e) {
            $error = '获取积分兑换规则失败：' . $e->getMessage();
            $show_rule_form = false;
        }
    }

    // 添加积分兑换规则时显示表单
    if (isset($_GET['action']) && $_GET['action'] == 'add_rule') {
        $show_rule_form = true;
    }
}

// 显示积分记录页面
elseif (isset($_GET['view']) && $_GET['view'] == 'records') {
    $view_point_records = true;

    // 设置筛选条件
    $filter_member_id = isset($_GET['member_id']) ? intval($_GET['member_id']) : 0;
    $filter_type = isset($_GET['type']) ? intval($_GET['type']) : 0;
    $filter_start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
    $filter_end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

    // 构建WHERE子句
    $where = [];
    $params = [];

    $where[] = "type IN (1, 2)"; // 只查询积分类型的记录

    if ($filter_member_id > 0) {
        $where[] = "member_id = ?";
        $params[] = $filter_member_id;
    }

    if ($filter_type > 0) {
        $where[] = "type = ?";
        $params[] = $filter_type;
    }

    if (!empty($filter_start_date)) {
        $where[] = "DATE(r.create_time) >= ?";
        $params[] = $filter_start_date;
    }

    if (!empty($filter_end_date)) {
        $where[] = "DATE(r.create_time) <= ?";
        $params[] = $filter_end_date;
    }

    $where_clause = !empty($where) ? " WHERE " . implode(" AND ", $where) : "";

    // 获取积分变动记录
    try {
        $sql = "
            SELECT r.*, m.member_no, m.name as member_name, m.phone,
                   CASE WHEN r.type = 1 THEN '积分增加' ELSE '积分消费' END as type_name
            FROM mem_record r
            JOIN mem_info m ON r.member_id = m.id
            $where_clause
            ORDER BY r.create_time DESC
            LIMIT 200
        ";

        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        $point_records = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取积分记录失败：' . $e->getMessage();
        $point_records = [];
    }

    // 获取所有会员（用于筛选）
    try {
        $stmt = $pdo->query("SELECT id, member_no, name, phone FROM mem_info ORDER BY id DESC");
        $members = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取会员列表失败：' . $e->getMessage();
        $members = [];
    }
}
// 默认显示积分兑换页面
else {
    // 获取所有会员
    try {
        $stmt = $pdo->query("SELECT * FROM mem_info WHERE status = 1 ORDER BY points DESC");
        $members = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取会员列表失败：' . $e->getMessage();
        $members = [];
    }

    // 获取所有启用的积分兑换规则
    try {
        // 如果表不存在，则跳过查询
        $table_exists = $pdo->query("SHOW TABLES LIKE 'mkt_point_rule'")->rowCount() > 0;

        if ($table_exists) {
            $stmt = $pdo->query("SELECT * FROM mkt_point_rule WHERE status = 1 ORDER BY points_required ASC");
            $point_rules = $stmt->fetchAll();
        } else {
            $point_rules = [];
        }
    } catch (PDOException $e) {
        $error = '获取积分兑换规则失败：' . $e->getMessage();
        $point_rules = [];
    }
}

// 页面顶部处理成功消息
if (isset($_GET['success'])) {
    if ($_GET['success'] == 'add_rule') {
        $success = '积分兑换规则添加成功！';
    } elseif ($_GET['success'] == 'edit_rule') {
        $success = '积分兑换规则更新成功！';
    } elseif ($_GET['success'] == 'exchange') {
        $success = '积分兑换成功！';
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员积分管理</h2>
            <div class="breadcrumb">
                <a href="index.php">会员营销</a> &gt; 积分管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <a href="points.php" class="btn <?php echo !$view_point_rules && !$view_point_records ? 'btn-primary' : 'btn-secondary'; ?>">积分兑换</a>
                <a href="points.php?view=rules" class="btn <?php echo $view_point_rules ? 'btn-primary' : 'btn-secondary'; ?>">积分规则设置</a>
                <a href="points.php?view=records" class="btn <?php echo $view_point_records ? 'btn-primary' : 'btn-secondary'; ?>">积分变动记录</a>
            </div>

            <?php if ($view_point_rules): ?>
                <!-- 积分规则设置视图 -->
                <div class="action-bar">
                    <a href="points.php?view=rules&action=add_rule" class="btn btn-add">添加积分兑换规则</a>
                </div>

                <?php if ($show_rule_form): ?>
                    <div class="form-container">
                        <h3><?php echo $edit_rule ? '编辑积分兑换规则' : '添加积分兑换规则'; ?></h3>
                        <form method="post" action="">
                            <input type="hidden" name="action" value="<?php echo $edit_rule ? 'edit_rule' : 'add_rule'; ?>">
                            <?php if ($edit_rule): ?>
                                <input type="hidden" name="rule_id" value="<?php echo $edit_rule['id']; ?>">
                            <?php endif; ?>

                            <div class="form-group">
                                <label for="rule_name">规则名称：</label>
                                <input type="text" id="rule_name" name="rule_name" value="<?php echo $edit_rule ? htmlspecialchars($edit_rule['rule_name']) : ''; ?>" required>
                            </div>

                            <div class="form-group">
                                <label for="points_required">所需积分：</label>
                                <input type="number" id="points_required" name="points_required" min="1" value="<?php echo $edit_rule ? intval($edit_rule['points_required']) : ''; ?>" required>
                            </div>

                            <div class="form-group">
                                <label for="reward_type">奖励类型：</label>
                                <select id="reward_type" name="reward_type">
                                    <option value="1" <?php echo ($edit_rule && $edit_rule['reward_type'] == 1) ? 'selected' : ''; ?>>商品折扣</option>
                                    <option value="2" <?php echo ($edit_rule && $edit_rule['reward_type'] == 2) ? 'selected' : ''; ?>>优惠券</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="reward_value">奖励值：</label>
                                <input type="number" id="reward_value" name="reward_value" min="0.01" step="0.01" value="<?php echo $edit_rule ? number_format($edit_rule['reward_value'], 2, '.', '') : ''; ?>" required>
                                <small>若为折扣，请输入0.1-1之间的数值表示折扣率；若为优惠券，请输入具体金额</small>
                            </div>

                            <div class="form-group">
                                <label for="status">状态：</label>
                                <select id="status" name="status">
                                    <option value="1" <?php echo ($edit_rule && $edit_rule['status'] == 1) ? 'selected' : ''; ?>>启用</option>
                                    <option value="0" <?php echo ($edit_rule && $edit_rule['status'] == 0) ? 'selected' : ''; ?>>禁用</option>
                                </select>
                            </div>

                            <div class="form-group">
                                <label for="description">规则描述：</label>
                                <textarea id="description" name="description" rows="3"><?php echo $edit_rule ? htmlspecialchars($edit_rule['description']) : ''; ?></textarea>
                            </div>

                            <div class="form-actions">
                                <button type="submit" class="btn btn-success">保存</button>
                                <a href="points.php?view=rules" class="btn btn-secondary">取消</a>
                            </div>
                        </form>
                    </div>
                <?php endif; ?>

                <div class="table-container">
                    <h3>积分兑换规则列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>规则名称</th>
                                <th>所需积分</th>
                                <th>奖励类型</th>
                                <th>奖励值</th>
                                <th>状态</th>
                                <th>创建时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($point_rules)): ?>
                                <tr>
                                    <td colspan="8" class="text-center">暂无积分兑换规则</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($point_rules as $rule): ?>
                                    <tr>
                                        <td><?php echo $rule['id']; ?></td>
                                        <td><?php echo htmlspecialchars($rule['rule_name']); ?></td>
                                        <td><?php echo number_format($rule['points_required']); ?></td>
                                        <td>
                                            <?php
                                            if ($rule['reward_type'] == 1) echo '商品折扣';
                                            elseif ($rule['reward_type'] == 2) echo '优惠券';
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($rule['reward_type'] == 1) {
                                                echo number_format($rule['reward_value'] * 10, 1) . '折';
                                            } else {
                                                echo number_format($rule['reward_value'], 2) . '元';
                                            }
                                            ?>
                                        </td>
                                        <td>
                                            <?php
                                            if ($rule['status'] == 1) echo '<span class="status-active">启用</span>';
                                            else echo '<span class="status-inactive">禁用</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($rule['create_time'])); ?></td>
                                        <td>
                                            <a href="points.php?view=rules&action=edit_rule&id=<?php echo $rule['id']; ?>" class="btn btn-sm btn-edit">编辑</a>
                                            <form method="post" action="" class="inline-form">
                                                <input type="hidden" name="action" value="delete_rule">
                                                <input type="hidden" name="rule_id" value="<?php echo $rule['id']; ?>">
                                                <button type="submit" class="btn btn-sm btn-danger" onclick="return confirm('确定要删除规则 \'<?php echo htmlspecialchars($rule['rule_name']); ?>\' 吗？');">删除</button>
                                            </form>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php elseif ($view_point_records): ?>
                <!-- 积分变动记录视图 -->
                <div class="filter-form">
                    <h3>筛选条件</h3>
                    <form method="get" action="">
                        <input type="hidden" name="view" value="records">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="member_id">会员：</label>
                                <select id="member_id" name="member_id">
                                    <option value="0">全部</option>
                                    <?php foreach ($members as $member): ?>
                                        <option value="<?php echo $member['id']; ?>" <?php echo ($filter_member_id == $member['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?> (<?php echo htmlspecialchars($member['member_no']); ?>)
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="type">记录类型：</label>
                                <select id="type" name="type">
                                    <option value="0" <?php echo ($filter_type == 0) ? 'selected' : ''; ?>>全部</option>
                                    <option value="1" <?php echo ($filter_type == 1) ? 'selected' : ''; ?>>积分增加</option>
                                    <option value="2" <?php echo ($filter_type == 2) ? 'selected' : ''; ?>>积分消费</option>
                                </select>
                            </div>
                        </div>

                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="start_date">开始日期：</label>
                                <input type="date" id="start_date" name="start_date" value="<?php echo $filter_start_date; ?>">
                            </div>

                            <div class="filter-item">
                                <label for="end_date">结束日期：</label>
                                <input type="date" id="end_date" name="end_date" value="<?php echo $filter_end_date; ?>">
                            </div>

                            <div class="filter-buttons">
                                <button type="submit" class="btn btn-primary">筛选</button>
                                <a href="points.php?view=records" class="btn btn-secondary">重置</a>
                            </div>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <h3>积分变动记录（最近200条）</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员</th>
                                <th>手机号码</th>
                                <th>记录类型</th>
                                <th>积分数量</th>
                                <th>备注</th>
                                <th>记录时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($point_records)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">暂无积分变动记录</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($point_records as $record): ?>
                                    <tr>
                                        <td><?php echo $record['id']; ?></td>
                                        <td><?php echo htmlspecialchars($record['member_name'] ?: '-'); ?> (<?php echo htmlspecialchars($record['member_no']); ?>)</td>
                                        <td><?php echo htmlspecialchars($record['phone']); ?></td>
                                        <td>
                                            <?php
                                            if ($record['type'] == 1) echo '<span class="status-active">积分增加</span>';
                                            else echo '<span class="status-inactive">积分消费</span>';
                                            ?>
                                        </td>
                                        <td><?php echo number_format($record['amount']); ?></td>
                                        <td><?php echo htmlspecialchars($record['remark'] ?: '-'); ?></td>
                                        <td><?php echo date('Y-m-d H:i', strtotime($record['create_time'])); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php else: ?>
                <!-- 积分兑换视图 -->
                <div class="form-container">
                    <h3>积分兑换</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="exchange_points">

                        <div class="form-group">
                            <label for="member_id">选择会员：</label>
                            <select id="member_id" name="member_id" required>
                                <option value="">请选择会员</option>
                                <?php foreach ($members as $member): ?>
                                    <option value="<?php echo $member['id']; ?>">
                                        <?php echo htmlspecialchars($member['name'] ? $member['name'] : $member['phone']); ?>
                                        (<?php echo htmlspecialchars($member['member_no']); ?>) -
                                        积分: <?php echo number_format($member['points']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="rule_id">选择兑换规则：</label>
                            <select id="rule_id" name="rule_id" required>
                                <option value="">请选择兑换规则</option>
                                <?php foreach ($point_rules as $rule): ?>
                                    <option value="<?php echo $rule['id']; ?>">
                                        <?php echo htmlspecialchars($rule['rule_name']); ?> -
                                        所需积分: <?php echo number_format($rule['points_required']); ?> -
                                        <?php
                                        if ($rule['reward_type'] == 1) {
                                            echo '奖励: ' . number_format($rule['reward_value'] * 10, 1) . '折';
                                        } else {
                                            echo '奖励: ' . number_format($rule['reward_value'], 2) . '元优惠券';
                                        }
                                        ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                            <?php if (empty($point_rules)): ?>
                                <small class="status-inactive">暂无可用兑换规则，请先添加规则</small>
                            <?php endif; ?>
                        </div>

                        <div class="form-group">
                            <label for="remark">备注：</label>
                            <textarea id="remark" name="remark" rows="2"></textarea>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success" <?php echo empty($point_rules) ? 'disabled' : ''; ?>>兑换</button>
                            <button type="reset" class="btn btn-secondary">重置</button>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <h3>会员积分列表</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>会员编号</th>
                                <th>姓名</th>
                                <th>手机号码</th>
                                <th>会员等级</th>
                                <th>积分余额</th>
                                <th>账户余额</th>
                                <th>累计消费</th>
                                <th>状态</th>
                                <th>注册时间</th>
                                <th>操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($members)): ?>
                                <tr>
                                    <td colspan="11" class="text-center">暂无会员数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($members as $member): ?>
                                    <tr>
                                        <td><?php echo $member['id']; ?></td>
                                        <td><?php echo htmlspecialchars($member['member_no']); ?></td>
                                        <td><?php echo htmlspecialchars($member['name'] ?: '-'); ?></td>
                                        <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                        <td>
                                            <?php
                                            if ($member['level'] == 1) echo '普通会员';
                                            elseif ($member['level'] == 2) echo '银卡会员';
                                            elseif ($member['level'] == 3) echo '金卡会员';
                                            elseif ($member['level'] == 4) echo '黑卡会员';
                                            ?>
                                        </td>
                                        <td><?php echo number_format($member['points']); ?></td>
                                        <td><?php echo number_format($member['balance'], 2); ?></td>
                                        <td><?php echo number_format($member['total_amount'], 2); ?></td>
                                        <td>
                                            <?php
                                            if ($member['status'] == 1) echo '<span class="status-active">正常</span>';
                                            else echo '<span class="status-inactive">禁用</span>';
                                            ?>
                                        </td>
                                        <td><?php echo date('Y-m-d', strtotime($member['create_time'])); ?></td>
                                        <td>
                                            <a href="points.php?view=records&member_id=<?php echo $member['id']; ?>" class="btn btn-sm btn-primary">查看记录</a>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>