<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order.delivery');

// 记录访问日志
record_log('访问外卖对接页面');

// 平台定义
$platforms = [
    1 => '美团外卖',
    2 => '饿了么',
    3 => '其他平台'
];

// 订单状态定义
$order_status = [
    1 => '待支付',
    2 => '待处理',
    3 => '制作中',
    4 => '已完成',
    5 => '已取消',
    6 => '已取餐'
];

// 处理操作请求
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] == 'confirm_order') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;

        if ($order_id > 0) {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 更新订单状态从待处理(2)到制作中(3)
                $stmt = $pdo->prepare("UPDATE order_main SET status = 3 WHERE id = ? AND status = 2");
                $result = $stmt->execute([$order_id]);

                if ($stmt->rowCount() > 0) {
                    // 添加状态变更记录
                    $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                    $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';
                    $remark = "确认外卖平台订单，开始制作";

                    $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, 3, ?, ?, ?)");
                    $stmt->execute([$order_id, $operator_id, $operator_name, $remark]);

                    // 提交事务
                    $pdo->commit();

                    $success = "已确认接单，订单ID: $order_id";
                    record_log("确认外卖平台订单：订单ID=$order_id");

                    // 重定向到当前页面以刷新显示
                    if (isset($_GET['view']) && $_GET['view'] == 'detail' && isset($_GET['id'])) {
                        header("Location: delivery.php?view=detail&id=" . $_GET['id'] . "&success=1");
                        exit;
                    } else {
                        header("Location: delivery.php?success=1");
                        exit;
                    }
                } else {
                    $pdo->rollBack();
                    $error = '订单状态更新失败，可能该订单已被处理或状态已改变';
                }
            } catch (PDOException $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '操作失败：' . $e->getMessage();
            }
        } else {
            $error = '无效的订单ID！';
        }
    } elseif ($_POST['action'] == 'reject_order') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $reason = isset($_POST['reason']) ? trim($_POST['reason']) : '';

        if ($order_id > 0) {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 更新订单状态为已取消(5)
                $stmt = $pdo->prepare("UPDATE order_main SET status = 5 WHERE id = ? AND status = 2");
                $result = $stmt->execute([$order_id]);

                if ($stmt->rowCount() > 0) {
                    // 添加状态变更记录
                    $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                    $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';
                    $remark = "拒绝外卖订单，原因：" . $reason;

                    $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, 5, ?, ?, ?)");
                    $stmt->execute([$order_id, $operator_id, $operator_name, $remark]);

                    // 提交事务
                    $pdo->commit();

                    $success = "已拒绝订单，订单ID: $order_id";
                    record_log("拒绝外卖平台订单：订单ID=$order_id，原因：$reason");

                    // 重定向到订单列表页面
                    header("Location: delivery.php?success=1");
                    exit;
                } else {
                    $pdo->rollBack();
                    $error = '订单状态更新失败，可能该订单已被处理或状态已改变';
                }
            } catch (PDOException $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '操作失败：' . $e->getMessage();
            }
        } else {
            $error = '无效的订单ID！';
        }
    } elseif ($_POST['action'] == 'update_status') {
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;
        $new_status = isset($_POST['new_status']) ? intval($_POST['new_status']) : 0;

        if ($order_id > 0 && $new_status > 0) {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 更新订单状态，只允许从制作中(3)到完成(4)
                $stmt = $pdo->prepare("UPDATE order_main SET status = ? WHERE id = ? AND status = 3");
                $result = $stmt->execute([$new_status, $order_id]);

                if ($stmt->rowCount() > 0) {
                    // 添加状态变更记录
                    $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                    $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';
                    $remark = "完成外卖订单制作";

                    $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, ?, ?, ?, ?)");
                    $stmt->execute([$order_id, $new_status, $operator_id, $operator_name, $remark]);

                    // 提交事务
                    $pdo->commit();

                    $success = "订单已完成制作，订单ID: $order_id";
                    record_log("外卖订单完成制作：订单ID=$order_id");

                    // 重定向到当前页面以刷新显示
                    if (isset($_GET['view']) && $_GET['view'] == 'detail' && isset($_GET['id'])) {
                        header("Location: delivery.php?view=detail&id=" . $_GET['id'] . "&success=1");
                        exit;
                    } else {
                        header("Location: delivery.php?success=1");
                        exit;
                    }
                } else {
                    $pdo->rollBack();
                    $error = '订单状态更新失败，可能该订单已被处理或状态已改变';
                }
            } catch (PDOException $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '操作失败：' . $e->getMessage();
            }
        } else {
            $error = '无效的订单ID或状态值！';
        }
    } elseif ($_POST['action'] == 'update_delivery') {
        $takeout_id = isset($_POST['takeout_id']) ? intval($_POST['takeout_id']) : 0;
        $rider_name = isset($_POST['rider_name']) ? trim($_POST['rider_name']) : '';
        $rider_phone = isset($_POST['rider_phone']) ? trim($_POST['rider_phone']) : '';
        $delivery_time = isset($_POST['delivery_time']) ? trim($_POST['delivery_time']) : '';
        $order_id = isset($_POST['order_id']) ? intval($_POST['order_id']) : 0;

        if ($takeout_id > 0 && $order_id > 0) {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 改为通过订单ID查询，避免使用takeout_id
                $stmt = $pdo->prepare("SELECT id FROM order_takeout WHERE order_id = ?");
                $stmt->execute([$order_id]);
                $takeout_record = $stmt->fetch();

                if (!$takeout_record) {
                    throw new Exception('订单ID:' . $order_id . '的外卖记录不存在');
                }

                // 使用查询到的实际ID进行更新
                $real_takeout_id = $takeout_record['id'];

                // 更新外卖配送信息，使用order_id而不是id
                $stmt = $pdo->prepare("UPDATE order_takeout SET rider_name = ?, rider_phone = ?, delivery_time = ? WHERE order_id = ?");
                $stmt->execute([$rider_name, $rider_phone, $delivery_time, $order_id]);

                // 添加状态变更记录
                $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';
                $remark = "更新外卖配送信息：骑手 $rider_name ($rider_phone)，预计送达时间 $delivery_time";

                $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, ?, ?, ?, ?)");
                $stmt->execute([$order_id, 4, $operator_id, $operator_name, $remark]);

                // 提交事务
                $pdo->commit();

                $success = "已成功更新配送信息";
                record_log("更新外卖配送信息：订单ID=$order_id，骑手=$rider_name，电话=$rider_phone，预计送达时间=$delivery_time");

                // 重定向到当前页面以刷新显示
                if (isset($_GET['view']) && $_GET['view'] == 'detail' && isset($_GET['id'])) {
                    header("Location: delivery.php?view=detail&id=" . $_GET['id'] . "&success=1");
                    exit;
                } else {
                    header("Location: delivery.php?success=1");
                    exit;
                }
            } catch (Exception $e) {
                // 回滚事务
                if ($pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = '更新配送信息失败：' . $e->getMessage();
            }
        } else {
            $error = '无效的订单ID或外卖记录ID！';
        }
    } elseif ($_POST['action'] == 'confirm_delivering') {
        // ... existing code ...
    }
}

// 获取外卖订单列表
$takeout_orders = [];
try {
    // 构建查询条件
    $where_conditions = [];
    $params = [];

    // 平台筛选
    $platform_filter = isset($_GET['platform']) ? intval($_GET['platform']) : 0;
    if ($platform_filter > 0) {
        $where_conditions[] = "t.platform = ?";
        $params[] = $platform_filter;
    }

    // 订单状态筛选
    $status_filter = isset($_GET['status']) ? intval($_GET['status']) : 0;
    if ($status_filter > 0) {
        $where_conditions[] = "o.status = ?";
        $params[] = $status_filter;
    }

    // 门店筛选
    $store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : 0;
    if ($store_id > 0) {
        $where_conditions[] = "o.store_id = ?";
        $params[] = $store_id;
    }

    // 日期筛选
    $date_filter = isset($_GET['date']) ? trim($_GET['date']) : '';
    if (!empty($date_filter)) {
        $where_conditions[] = "DATE(o.create_time) = ?";
        $params[] = $date_filter;
    }

    // 构建完整WHERE子句
    $where_clause = !empty($where_conditions) ? "WHERE " . implode(" AND ", $where_conditions) : "";

    // 查询外卖订单数据
    $sql = "
        SELECT o.*, t.*, s.store_name
        FROM order_takeout t
        JOIN order_main o ON t.order_id = o.id
        LEFT JOIN store_info s ON o.store_id = s.id
        $where_clause
        ORDER BY o.create_time DESC
        LIMIT 100
    ";

    $stmt = $pdo->prepare($sql);
    if (!empty($params)) {
        $stmt->execute($params);
    } else {
        $stmt->execute();
    }

    $takeout_orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取外卖订单列表失败：' . $e->getMessage();
}

// 获取门店列表用于筛选
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info WHERE status = 1 ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $stores = [];
}

// 获取单个外卖订单详情（如果指定了ID参数）
$takeout_detail = null;
$order_detail = null;
$order_items = [];

if (isset($_GET['view']) && $_GET['view'] == 'detail' && isset($_GET['id'])) {
    $detail_id = intval($_GET['id']);

    try {
        // 获取外卖订单详情
        $stmt = $pdo->prepare("
            SELECT t.*, o.*, s.store_name
            FROM order_takeout t
            JOIN order_main o ON t.order_id = o.id
            LEFT JOIN store_info s ON o.store_id = s.id
            WHERE t.id = ?
        ");
        $stmt->execute([$detail_id]);
        $takeout_detail = $stmt->fetch();

        if ($takeout_detail) {
            // 获取订单明细
            $stmt = $pdo->prepare("SELECT * FROM order_item WHERE order_id = ?");
            $stmt->execute([$takeout_detail['order_id']]);
            $order_items = $stmt->fetchAll();
        }
    } catch (PDOException $e) {
        $error = '获取外卖订单详情失败：' . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>外卖对接</h2>
            <div class="breadcrumb">
                <a href="index.php">订单与销售管理</a> &gt; 外卖对接
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success) || isset($_GET['success'])): ?>
                <div class="alert alert-success"><?php echo isset($success) ? $success : '操作成功！'; ?></div>
            <?php endif; ?>

            <?php if (isset($_GET['view']) && $_GET['view'] == 'detail' && $takeout_detail): ?>
                <!-- 外卖订单详情视图 -->
                <div class="action-bar">
                    <a href="delivery.php" class="btn btn-secondary">返回外卖订单列表</a>

                    <?php if ($takeout_detail['status'] == 2): ?>
                        <form method="post" action="" class="inline-form">
                            <input type="hidden" name="action" value="confirm_order">
                            <input type="hidden" name="order_id" value="<?php echo $takeout_detail['order_id']; ?>">
                            <button type="submit" class="btn btn-primary">确认接单</button>
                        </form>

                        <button type="button" class="btn btn-danger" onclick="showRejectForm()">拒绝订单</button>
                    <?php elseif ($takeout_detail['status'] == 3): ?>
                        <form method="post" action="" class="inline-form">
                            <input type="hidden" name="action" value="update_status">
                            <input type="hidden" name="order_id" value="<?php echo $takeout_detail['order_id']; ?>">
                            <input type="hidden" name="new_status" value="4">
                            <button type="submit" class="btn btn-success">完成制作</button>
                        </form>
                    <?php elseif ($takeout_detail['status'] == 4): ?>
                        <button type="button" class="btn btn-primary" onclick="showDeliveryForm()">更新配送信息</button>
                    <?php endif; ?>
                </div>

                <!-- 拒绝订单表单 -->
                <div id="rejectForm" style="display: none;" class="form-container">
                    <h3>拒绝订单</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="reject_order">
                        <input type="hidden" name="order_id" value="<?php echo $takeout_detail['order_id']; ?>">

                        <div class="form-group">
                            <label for="reason">拒绝原因：</label>
                            <select name="reason" id="reason">
                                <option value="门店太忙">门店太忙</option>
                                <option value="商品售罄">商品售罄</option>
                                <option value="超出配送范围">超出配送范围</option>
                                <option value="其他原因">其他原因</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-danger">确认拒绝</button>
                            <button type="button" class="btn btn-secondary" onclick="hideRejectForm()">取消</button>
                        </div>
                    </form>
                </div>

                <!-- 更新配送信息表单 -->
                <div id="deliveryForm" style="display: none;" class="form-container">
                    <h3>更新配送信息</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update_delivery">
                        <input type="hidden" name="takeout_id" value="<?php echo $takeout_detail['id']; ?>">
                        <input type="hidden" name="order_id" value="<?php echo $takeout_detail['order_id']; ?>">

                        <div class="form-group">
                            <label for="rider_name">骑手姓名：</label>
                            <input type="text" name="rider_name" id="rider_name" value="<?php echo htmlspecialchars($takeout_detail['rider_name'] ?: ''); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="rider_phone">骑手电话：</label>
                            <input type="text" name="rider_phone" id="rider_phone" value="<?php echo htmlspecialchars($takeout_detail['rider_phone'] ?: ''); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="delivery_time">预计送达时间：</label>
                            <input type="datetime-local" name="delivery_time" id="delivery_time" value="<?php echo $takeout_detail['delivery_time'] ? date('Y-m-d\TH:i', strtotime($takeout_detail['delivery_time'])) : date('Y-m-d\TH:i', strtotime('+30 minutes')); ?>" required>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-primary">更新信息</button>
                            <button type="button" class="btn btn-secondary" onclick="hideDeliveryForm()">取消</button>
                        </div>
                    </form>
                </div>

                <div class="info-box">
                    <h3>外卖订单信息</h3>
                    <table class="info-table">
                        <tr>
                            <td width="120">订单编号：</td>
                            <td><?php echo htmlspecialchars($takeout_detail['order_no']); ?></td>
                            <td width="120">平台订单号：</td>
                            <td><?php echo htmlspecialchars($takeout_detail['platform_order_no']); ?></td>
                        </tr>
                        <tr>
                            <td>外卖平台：</td>
                            <td><?php echo $platforms[$takeout_detail['platform']]; ?></td>
                            <td>门店：</td>
                            <td><?php echo htmlspecialchars($takeout_detail['store_name']); ?></td>
                        </tr>
                        <tr>
                            <td>订单状态：</td>
                            <td>
                                <?php
                                $bg_color = '';
                                switch ($takeout_detail['status']) {
                                    case 1:
                                    case 2:
                                        $bg_color = '#ffc107'; // 黄色
                                        break;
                                    case 3:
                                        $bg_color = '#007bff'; // 蓝色
                                        break;
                                    case 4:
                                    case 6:
                                        $bg_color = '#28a745'; // 绿色
                                        break;
                                    case 5:
                                        $bg_color = '#dc3545'; // 红色
                                        break;
                                }
                                ?>
                                <span class="status-tag" style="background-color: <?php echo $bg_color; ?>;">
                                    <?php echo $order_status[$takeout_detail['status']]; ?>
                                </span>
                            </td>
                            <td>创建时间：</td>
                            <td><?php echo $takeout_detail['create_time']; ?></td>
                        </tr>
                        <tr>
                            <td>订单金额：</td>
                            <td>¥<?php echo number_format($takeout_detail['total_amount'], 2); ?></td>
                            <td>配送费：</td>
                            <td>¥<?php echo number_format($takeout_detail['delivery_fee'], 2); ?></td>
                        </tr>
                        <tr>
                            <td>骑手信息：</td>
                            <td colspan="3">
                                <?php if (!empty($takeout_detail['rider_name']) && !empty($takeout_detail['rider_phone'])): ?>
                                    <?php echo htmlspecialchars($takeout_detail['rider_name']); ?> (<?php echo htmlspecialchars($takeout_detail['rider_phone']); ?>)
                                <?php else: ?>
                                    暂无骑手信息
                                <?php endif; ?>
                            </td>
                        </tr>
                        <tr>
                            <td>预计送达：</td>
                            <td colspan="3">
                                <?php echo !empty($takeout_detail['delivery_time']) ? $takeout_detail['delivery_time'] : '暂无预计送达时间'; ?>
                            </td>
                        </tr>
                    </table>
                </div>

                <h3>订单明细</h3>
                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>产品名称</th>
                                <th>属性</th>
                                <th>单价</th>
                                <th>数量</th>
                                <th>小计</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($order_items)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无订单明细数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($order_items as $item): ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($item['product_name']); ?></td>
                                        <td><?php echo htmlspecialchars($item['attributes'] ?: '无'); ?></td>
                                        <td>¥<?php echo number_format($item['price'], 2); ?></td>
                                        <td><?php echo $item['quantity']; ?></td>
                                        <td>¥<?php echo number_format($item['subtotal'], 2); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                        <tfoot>
                            <tr>
                                <td colspan="4" class="text-right"><strong>商品金额：</strong></td>
                                <td>¥<?php echo number_format($takeout_detail['total_amount'], 2); ?></td>
                            </tr>
                            <tr>
                                <td colspan="4" class="text-right"><strong>配送费：</strong></td>
                                <td>¥<?php echo number_format($takeout_detail['delivery_fee'], 2); ?></td>
                            </tr>
                            <tr>
                                <td colspan="4" class="text-right"><strong>总计金额：</strong></td>
                                <td><strong>¥<?php echo number_format($takeout_detail['total_amount'] + $takeout_detail['delivery_fee'], 2); ?></strong></td>
                            </tr>
                        </tfoot>
                    </table>
                </div>

            <?php else: ?>
                <!-- 外卖订单列表视图 -->
                <div class="filter-form">
                    <form method="get" action="">
                        <div class="filter-row">
                            <div class="filter-item">
                                <label for="platform">外卖平台：</label>
                                <select id="platform" name="platform">
                                    <option value="">全部平台</option>
                                    <?php foreach ($platforms as $id => $name): ?>
                                        <option value="<?php echo $id; ?>" <?php echo (isset($_GET['platform']) && $_GET['platform'] == $id) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($name); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="status">订单状态：</label>
                                <select id="status" name="status">
                                    <option value="">全部状态</option>
                                    <?php foreach ($order_status as $id => $name): ?>
                                        <option value="<?php echo $id; ?>" <?php echo (isset($_GET['status']) && $_GET['status'] == $id) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($name); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="store_id">门店：</label>
                                <select id="store_id" name="store_id">
                                    <option value="">全部门店</option>
                                    <?php foreach ($stores as $store): ?>
                                        <option value="<?php echo $store['id']; ?>" <?php echo (isset($_GET['store_id']) && $_GET['store_id'] == $store['id']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($store['store_name']); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>

                            <div class="filter-item">
                                <label for="date">日期：</label>
                                <input type="date" id="date" name="date" value="<?php echo isset($_GET['date']) ? htmlspecialchars($_GET['date']) : ''; ?>">
                            </div>
                        </div>

                        <div class="filter-buttons">
                            <button type="submit" class="btn btn-primary">筛选</button>
                            <a href="delivery.php" class="btn btn-secondary">重置</a>
                        </div>
                    </form>
                </div>

                <div class="table-container">
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>平台</th>
                                <th>订单号</th>
                                <th>平台订单号</th>
                                <th>门店</th>
                                <th>金额</th>
                                <th>配送费</th>
                                <th>骑手</th>
                                <th style="min-width: 80px;">状态</th>
                                <th>预计送达</th>
                                <th>创建时间</th>
                                <th style="min-width: 100px;">操作</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($takeout_orders)): ?>
                                <tr>
                                    <td colspan="11" class="text-center">暂无外卖订单数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($takeout_orders as $order): ?>
                                    <tr>
                                        <td><?php echo $platforms[$order['platform']]; ?></td>
                                        <td><?php echo htmlspecialchars($order['order_no']); ?></td>
                                        <td><?php echo htmlspecialchars($order['platform_order_no']); ?></td>
                                        <td><?php echo htmlspecialchars($order['store_name']); ?></td>
                                        <td>¥<?php echo number_format($order['total_amount'], 2); ?></td>
                                        <td>¥<?php echo number_format($order['delivery_fee'], 2); ?></td>
                                        <td><?php echo !empty($order['rider_name']) ? htmlspecialchars($order['rider_name']) : '-'; ?></td>
                                        <td>
                                            <?php
                                            $bg_color = '';
                                            switch ($order['status']) {
                                                case 1:
                                                case 2:
                                                    $bg_color = '#ffc107'; // 黄色
                                                    break;
                                                case 3:
                                                    $bg_color = '#007bff'; // 蓝色
                                                    break;
                                                case 4:
                                                case 6:
                                                    $bg_color = '#28a745'; // 绿色
                                                    break;
                                                case 5:
                                                    $bg_color = '#dc3545'; // 红色
                                                    break;
                                            }
                                            ?>
                                            <span class="status-tag" style="background-color: <?php echo $bg_color; ?>;">
                                                <?php echo $order_status[$order['status']]; ?>
                                            </span>
                                        </td>
                                        <td><?php echo !empty($order['delivery_time']) ? (new DateTime($order['delivery_time']))->format('m-d H:i') : '-'; ?></td>
                                        <td><?php echo (new DateTime($order['create_time']))->format('m-d H:i'); ?></td>
                                        <td style="white-space: nowrap;">
                                            <a href="delivery.php?view=detail&id=<?php echo $order['id']; ?>" class="btn btn-sm btn-details">详情</a>

                                            <?php if ($order['status'] == 2): ?>
                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="confirm_order">
                                                    <input type="hidden" name="order_id" value="<?php echo $order['order_id']; ?>">
                                                    <button type="submit" class="btn btn-sm btn-primary">接单</button>
                                                </form>
                                            <?php elseif ($order['status'] == 3): ?>
                                                <form method="post" action="" class="inline-form">
                                                    <input type="hidden" name="action" value="update_status">
                                                    <input type="hidden" name="order_id" value="<?php echo $order['order_id']; ?>">
                                                    <input type="hidden" name="new_status" value="4">
                                                    <button type="submit" class="btn btn-sm btn-success">完成</button>
                                                </form>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 显示拒绝订单表单
        function showRejectForm() {
            document.getElementById('rejectForm').style.display = 'block';
        }

        // 隐藏拒绝订单表单
        function hideRejectForm() {
            document.getElementById('rejectForm').style.display = 'none';
        }

        // 显示更新配送信息表单
        function showDeliveryForm() {
            document.getElementById('deliveryForm').style.display = 'block';
        }

        // 隐藏更新配送信息表单
        function hideDeliveryForm() {
            document.getElementById('deliveryForm').style.display = 'none';
        }

        // 自动刷新订单列表
        <?php if (!isset($_GET['view']) || $_GET['view'] != 'detail'): ?>
            setTimeout(function() {
                location.reload();
            }, 120000); // 每2分钟刷新一次
        <?php endif; ?>
    </script>
</body>

</html>