<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order');

// 记录访问日志
record_log('访问订单与销售管理页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>订单与销售管理</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>今日订单</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM order_main WHERE DATE(create_time) = CURDATE()");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">待处理：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM order_main WHERE DATE(create_time) = CURDATE() AND status IN (1, 2)");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>今日销售额</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT SUM(pay_amount) as total FROM order_main WHERE DATE(create_time) = CURDATE() AND status > 1");
                                        $result = $stmt->fetch();
                                        echo number_format($result['total'] ?: 0, 2);
                                        ?></div>
                    <div class="desc">订单均价：<?php
                                            $stmt = $pdo->query("SELECT AVG(pay_amount) as avg FROM order_main WHERE DATE(create_time) = CURDATE() AND status > 1");
                                            $result = $stmt->fetch();
                                            echo number_format($result['avg'] ?: 0, 2);
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>订单类型</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT 
                                            SUM(CASE WHEN order_type = 1 THEN 1 ELSE 0 END) as dine_in,
                                            SUM(CASE WHEN order_type = 2 THEN 1 ELSE 0 END) as takeout,
                                            SUM(CASE WHEN order_type = 3 THEN 1 ELSE 0 END) as delivery
                                        FROM order_main WHERE DATE(create_time) = CURDATE()");
                                        $result = $stmt->fetch();
                                        echo "堂食: {$result['dine_in']}";
                                        ?></div>
                    <div class="desc">外带: <?php echo $result['takeout']; ?> | 外卖: <?php echo $result['delivery']; ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>支付方式</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM pay_record WHERE DATE(create_time) = CURDATE() AND status = 3");
                                        $result = $stmt->fetch();
                                        echo "已支付: {$result['count']}";
                                        ?></div>
                    <div class="desc">退款：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM pay_record WHERE DATE(create_time) = CURDATE() AND status = 4");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="pos.php" class="function-link">
                    <h3>前台点单系统</h3>
                </a>
                <a href="category.php" class="function-link">
                    <h3>订单自动分类</h3>
                </a>
                <a href="payment.php" class="function-link">
                    <h3>支付管理</h3>
                </a>
                <a href="process.php" class="function-link">
                    <h3>订单处理</h3>
                </a>
                <a href="delivery.php" class="function-link">
                    <h3>外卖对接</h3>
                </a>
            </div>

            <h2>最近订单</h2>
            <div class="recent-orders">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>订单编号</th>
                            <th>门店</th>
                            <th>类型</th>
                            <th>来源</th>
                            <th>金额</th>
                            <th>状态</th>
                            <th>下单时间</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT o.*, s.store_name 
                                    FROM order_main o
                                    JOIN store_info s ON o.store_id = s.id
                                    ORDER BY o.create_time DESC LIMIT 8");

                        $orderTypes = [1 => '堂食', 2 => '外带', 3 => '外卖'];
                        $orderSources = [1 => '店员下单', 2 => '自助点单', 3 => '扫码点单', 4 => '外卖平台'];
                        $orderStatus = [1 => '待支付', 2 => '待处理', 3 => '制作中', 4 => '已完成', 5 => '已取消'];

                        while ($row = $stmt->fetch()) {
                            echo "<tr>
                                <td>{$row['order_no']}</td>
                                <td>{$row['store_name']}</td>
                                <td>{$orderTypes[$row['order_type']]}</td>
                                <td>{$orderSources[$row['order_source']]}</td>
                                <td>" . number_format($row['pay_amount'], 2) . "</td>
                                <td>{$orderStatus[$row['status']]}</td>
                                <td>" . date('m-d H:i', strtotime($row['create_time'])) . "</td>
                            </tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>今日支付统计</h2>
            <div class="payment-stats">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>支付方式</th>
                            <th>交易笔数</th>
                            <th>交易金额</th>
                            <th>占比</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("SELECT 
                                pay_type,
                                COUNT(*) as count,
                                SUM(pay_amount) as total_amount
                            FROM pay_record 
                            WHERE DATE(create_time) = CURDATE() AND status = 3
                            GROUP BY pay_type
                            ORDER BY total_amount DESC");

                        $payTypes = [1 => '现金', 2 => '微信', 3 => '支付宝', 4 => '银行卡', 5 => '会员余额'];

                        $totalAmount = 0;
                        $payData = [];

                        while ($row = $stmt->fetch()) {
                            $payData[] = $row;
                            $totalAmount += $row['total_amount'];
                        }

                        foreach ($payData as $row) {
                            $percentage = $totalAmount > 0 ? round(($row['total_amount'] / $totalAmount) * 100, 2) : 0;
                            echo "<tr>
                                <td>{$payTypes[$row['pay_type']]}</td>
                                <td>{$row['count']}</td>
                                <td>" . number_format($row['total_amount'], 2) . "</td>
                                <td>{$percentage}%</td>
                            </tr>";
                        }

                        if (empty($payData)) {
                            echo "<tr><td colspan='4' style='text-align:center'>今日暂无支付记录</td></tr>";
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>