<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('order');

// 记录访问日志
record_log('访问前台点单系统页面');

// 获取所有门店列表
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店列表失败：' . $e->getMessage();
    $stores = [];
}

// 获取当前选择的门店ID
$store_id = isset($_GET['store_id']) ? intval($_GET['store_id']) : (count($stores) > 0 ? $stores[0]['id'] : 0);

// 获取所有会员列表
$members = [];
try {
    $stmt = $pdo->query("SELECT id, member_no, name, phone FROM mem_info WHERE status = 1 ORDER BY id");
    $members = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取会员列表失败：' . $e->getMessage();
}

// 获取当前选择的会员ID
$member_id = isset($_GET['member_id']) ? intval($_GET['member_id']) : 0;

// 获取产品列表
$products = [];
if ($store_id > 0) {
    try {
        // 这里应该根据实际的产品表结构来修改SQL
        $stmt = $pdo->prepare("SELECT id, name, price, category FROM product_items WHERE status = 1 ORDER BY category, id");
        $stmt->execute();
        $products = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取产品列表失败：' . $e->getMessage();
    }
}

// 处理订单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    if ($_POST['action'] == 'create_order') {
        $order_store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $order_type = isset($_POST['order_type']) ? intval($_POST['order_type']) : 1;
        $order_source = isset($_POST['order_source']) ? intval($_POST['order_source']) : 1;
        $member_id = isset($_POST['member_id']) && !empty($_POST['member_id']) ? intval($_POST['member_id']) : null;
        $product_ids = isset($_POST['product_id']) ? $_POST['product_id'] : [];
        $quantities = isset($_POST['quantity']) ? $_POST['quantity'] : [];
        $attributes = isset($_POST['attributes']) ? $_POST['attributes'] : [];

        // 验证数据
        if ($order_store_id <= 0) {
            $error = '请选择门店！';
        } elseif (empty($product_ids)) {
            $error = '请选择至少一个产品！';
        } else {
            try {
                // 开始事务
                $pdo->beginTransaction();

                // 生成订单编号
                $order_no = 'ORD' . date('YmdHis') . rand(100, 999);

                // 计算订单金额
                $total_amount = 0;
                $items = [];

                for ($i = 0; $i < count($product_ids); $i++) {
                    $product_id = intval($product_ids[$i]);
                    $quantity = intval($quantities[$i]);
                    $attribute = isset($attributes[$i]) ? $attributes[$i] : '';

                    if ($product_id > 0 && $quantity > 0) {
                        // 获取产品信息
                        $stmt = $pdo->prepare("SELECT id, name, price FROM product_items WHERE id = ?");
                        $stmt->execute([$product_id]);
                        $product = $stmt->fetch();

                        if ($product) {
                            $subtotal = $product['price'] * $quantity;
                            $total_amount += $subtotal;

                            $items[] = [
                                'product_id' => $product_id,
                                'product_name' => $product['name'],
                                'price' => $product['price'],
                                'quantity' => $quantity,
                                'subtotal' => $subtotal,
                                'attributes' => $attribute
                            ];
                        }
                    }
                }

                // 创建订单
                $stmt = $pdo->prepare("INSERT INTO order_main (order_no, store_id, order_type, order_source, total_amount, pay_amount, member_id, status) VALUES (?, ?, ?, ?, ?, ?, ?, 1)");
                $stmt->execute([$order_no, $order_store_id, $order_type, $order_source, $total_amount, $total_amount, $member_id]);
                $order_id = $pdo->lastInsertId();

                // 如果是外卖订单且来源是外卖平台，则添加外卖信息
                if ($order_type == 3 && $order_source == 4) {
                    $takeout_platform = isset($_POST['takeout_platform']) ? intval($_POST['takeout_platform']) : 1;
                    $platform_order_no = isset($_POST['platform_order_no']) ? trim($_POST['platform_order_no']) : '';
                    $delivery_fee = isset($_POST['delivery_fee']) ? floatval($_POST['delivery_fee']) : 0;
                    $rider_name = isset($_POST['rider_name']) ? trim($_POST['rider_name']) : null;
                    $rider_phone = isset($_POST['rider_phone']) ? trim($_POST['rider_phone']) : null;
                    $delivery_time = isset($_POST['delivery_time']) && !empty($_POST['delivery_time']) ? $_POST['delivery_time'] : null;

                    // 如果没有输入平台订单号，则生成一个默认的
                    if (empty($platform_order_no)) {
                        $platform_prefixes = [1 => 'MT', 2 => 'ELM', 3 => 'OTH'];
                        $prefix = isset($platform_prefixes[$takeout_platform]) ? $platform_prefixes[$takeout_platform] : 'OTH';
                        $platform_order_no = $prefix . date('YmdHis') . rand(100, 999);
                    }

                    $stmt = $pdo->prepare("INSERT INTO order_takeout (order_id, platform, platform_order_no, delivery_fee, rider_name, rider_phone, delivery_time) VALUES (?, ?, ?, ?, ?, ?, ?)");
                    $stmt->execute([$order_id, $takeout_platform, $platform_order_no, $delivery_fee, $rider_name, $rider_phone, $delivery_time]);
                }

                // 添加订单明细
                foreach ($items as $item) {
                    $stmt = $pdo->prepare("INSERT INTO order_item (order_id, product_id, product_name, price, quantity, subtotal, attributes) VALUES (?, ?, ?, ?, ?, ?, ?)");
                    $stmt->execute([
                        $order_id,
                        $item['product_id'],
                        $item['product_name'],
                        $item['price'],
                        $item['quantity'],
                        $item['subtotal'],
                        $item['attributes']
                    ]);
                }

                // 添加订单状态记录
                $operator_id = isset($_SESSION['user_id']) ? $_SESSION['user_id'] : null;
                $operator_name = isset($_SESSION['username']) ? $_SESSION['username'] : '系统';
                $stmt = $pdo->prepare("INSERT INTO order_status (order_id, status, operator_id, operator_name, remark) VALUES (?, 1, ?, ?, '创建订单')");
                $stmt->execute([$order_id, $operator_id, $operator_name]);

                // 提交事务
                $pdo->commit();

                // 跳转到支付页面
                header("Location: payment.php?order_id=" . $order_id);
                exit;
            } catch (PDOException $e) {
                // 回滚事务
                $pdo->rollBack();
                $error = '创建订单失败：' . $e->getMessage();
            }
        }
    }
}

// 获取会员信息（用于下拉选择，已在前面获取）
// 获取所有会员列表在前面已实现
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>前台点单系统</h2>
            <div class="breadcrumb">
                <a href="index.php">订单与销售管理</a> &gt; 前台点单系统
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 门店选择表单 -->
            <div class="filter-form">
                <form method="get" action="">
                    <div class="filter-row">
                        <div class="filter-item">
                            <label for="store_id">选择门店：</label>
                            <select id="store_id" name="store_id" onchange="this.form.submit()">
                                <option value="">-- 请选择门店 --</option>
                                <?php foreach ($stores as $store): ?>
                                    <option value="<?php echo $store['id']; ?>" <?php echo ($store_id == $store['id']) ? 'selected' : ''; ?>>
                                        <?php echo htmlspecialchars($store['store_name']); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                </form>
            </div>

            <?php if ($store_id > 0): ?>
                <!-- 创建订单表单 -->
                <div class="form-container">
                    <h3>创建新订单</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="create_order">
                        <input type="hidden" name="store_id" value="<?php echo $store_id; ?>">

                        <div class="form-group">
                            <label for="order_type">订单类型：</label>
                            <select id="order_type" name="order_type">
                                <option value="1">堂食</option>
                                <option value="2">外带</option>
                                <option value="3">外卖</option>
                            </select>
                        </div>

                        <div class="form-group">
                            <label for="order_source">订单来源：</label>
                            <select id="order_source" name="order_source" onchange="toggleTakeoutFields()">
                                <option value="1">店员下单</option>
                                <option value="2">自助点单</option>
                                <option value="3">扫码点单</option>
                                <option value="4">外卖平台</option>
                            </select>
                        </div>

                        <!-- 外卖平台相关字段，初始隐藏 -->
                        <div id="takeout_fields" style="display: none;">
                            <div class="form-group">
                                <label for="takeout_platform">外卖平台：</label>
                                <select id="takeout_platform" name="takeout_platform">
                                    <option value="1">美团外卖</option>
                                    <option value="2">饿了么</option>
                                    <option value="3">其他平台</option>
                                </select>
                            </div>
                            <div class="form-group">
                                <label for="platform_order_no">平台订单号：</label>
                                <input type="text" id="platform_order_no" name="platform_order_no" placeholder="请输入外卖平台订单号">
                            </div>
                            <div class="form-group">
                                <label for="delivery_fee">配送费：</label>
                                <input type="number" id="delivery_fee" name="delivery_fee" min="0" step="0.01" value="0.00">
                            </div>
                            <div class="form-group">
                                <label for="rider_name">骑手姓名：</label>
                                <input type="text" id="rider_name" name="rider_name" placeholder="选填">
                            </div>
                            <div class="form-group">
                                <label for="rider_phone">骑手电话：</label>
                                <input type="text" id="rider_phone" name="rider_phone" placeholder="选填">
                            </div>
                            <div class="form-group">
                                <label for="delivery_time">预计送达时间：</label>
                                <input type="datetime-local" id="delivery_time" name="delivery_time">
                            </div>
                        </div>

                        <!-- 会员搜索 -->
                        <div class="form-group">
                            <label>会员信息（可选）：</label>
                            <div class="filter-row">
                                <div class="filter-item" style="flex: 2;">
                                    <select name="member_id">
                                        <option value="">-- 选择会员 --</option>
                                        <?php foreach ($members as $member): ?>
                                            <option value="<?php echo $member['id']; ?>">
                                                <?php echo htmlspecialchars($member['member_no'] . ' - ' . $member['name'] . ' (' . $member['phone'] . ')'); ?>
                                            </option>
                                        <?php endforeach; ?>
                                    </select>
                                </div>
                            </div>
                        </div>

                        <!-- 产品列表 -->
                        <h4>选择产品</h4>
                        <div class="table-container">
                            <table class="data-table">
                                <thead>
                                    <tr>
                                        <th>选择</th>
                                        <th>产品名称</th>
                                        <th>分类</th>
                                        <th>价格</th>
                                        <th>数量</th>
                                        <th>属性设置</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (empty($products)): ?>
                                        <tr>
                                            <td colspan="6" class="text-center">暂无产品数据</td>
                                        </tr>
                                    <?php else: ?>
                                        <?php foreach ($products as $product): ?>
                                            <tr>
                                                <td>
                                                    <input type="checkbox" name="product_id[]" value="<?php echo $product['id']; ?>">
                                                </td>
                                                <td><?php echo htmlspecialchars($product['name']); ?></td>
                                                <td><?php echo htmlspecialchars($product['category']); ?></td>
                                                <td><?php echo number_format($product['price'], 2); ?></td>
                                                <td>
                                                    <input type="number" name="quantity[]" value="1" min="1" max="99" style="width: 60px;">
                                                </td>
                                                <td>
                                                    <input type="text" name="attributes[]" placeholder="如：热/冰，糖度等" style="width: 150px;">
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">创建订单并进入支付</button>
                            <a href="index.php" class="btn btn-secondary">取消</a>
                        </div>
                    </form>
                </div>
            <?php else: ?>
                <div class="alert alert-danger">请先选择一个门店进行点单</div>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 根据订单来源和类型控制外卖字段的显示隐藏
        function toggleTakeoutFields() {
            var orderSource = document.getElementById('order_source').value;
            var orderType = document.getElementById('order_type').value;
            var takeoutFields = document.getElementById('takeout_fields');

            // 如果是外卖平台来源，则显示外卖字段，并自动设置订单类型为外卖
            if (orderSource == '4') {
                takeoutFields.style.display = 'block';
                document.getElementById('order_type').value = '3'; // 设置为外卖类型
            } else {
                takeoutFields.style.display = 'none';
            }
        }

        // 页面加载时初始化
        document.addEventListener('DOMContentLoaded', function() {
            // 监听订单类型变化
            document.getElementById('order_type').addEventListener('change', function() {
                toggleTakeoutFields();
            });

            // 初始检查
            toggleTakeoutFields();
        });
    </script>
</body>

</html>