<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('product');

// 记录访问日志
record_log('访问产品管理页面');
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>产品管理</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>产品总数</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM product_items");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">在售产品：<?php
                                            $stmt = $pdo->query("SELECT COUNT(*) as count FROM product_items WHERE status = 1");
                                            $result = $stmt->fetch();
                                            echo $result['count'];
                                            ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>产品分类</h3>
                    <div class="number"><?php
                                        $stmt = $pdo->query("SELECT COUNT(*) as count FROM product_category");
                                        $result = $stmt->fetch();
                                        echo $result['count'];
                                        ?></div>
                    <div class="desc">分类总数</div>
                </div>

                <div class="dashboard-card">
                    <h3>今日销量</h3>
                    <div class="number"><?php
                                        // 修正：使用order_main表的create_time
                                        $stmt = $pdo->query("
                                            SELECT SUM(oi.quantity) as total 
                                            FROM order_item oi
                                            JOIN order_main om ON oi.order_id = om.id
                                            WHERE DATE(om.create_time) = CURDATE()
                                        ");
                                        $result = $stmt->fetch();
                                        echo $result['total'] ? $result['total'] : 0;
                                        ?></div>
                    <div class="desc">销售总数</div>
                </div>

                <div class="dashboard-card">
                    <h3>畅销品</h3>
                    <div class="number"><?php
                                        // 修复GROUP BY错误，使用MAX()聚合函数处理product_name
                                        $stmt = $pdo->query("
                                            SELECT MAX(product_name) as product_name 
                                            FROM order_item 
                                            GROUP BY product_id 
                                            ORDER BY SUM(quantity) DESC 
                                            LIMIT 1
                                        ");
                                        $result = $stmt->fetch();
                                        echo $result ? $result['product_name'] : '暂无数据';
                                        ?></div>
                    <div class="desc">最畅销产品</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="catalog.php" class="function-link">
                    <h3>产品目录</h3>
                </a>
                <a href="category.php" class="function-link">
                    <h3>分类管理</h3>
                </a>
            </div>

            <h2>产品概览</h2>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>分类</th>
                            <th>价格</th>
                            <th>销量</th>
                            <th>状态</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            $stmt = $pdo->query("
                                SELECT p.name, c.name as category_name, p.price, 
                                IFNULL((SELECT SUM(quantity) FROM order_item WHERE product_id = p.id), 0) as sales_total,
                                p.status
                                FROM product_items p
                                LEFT JOIN product_category c ON p.category = c.id
                                ORDER BY sales_total DESC, p.id DESC
                                LIMIT 10
                            ");
                            $products = $stmt->fetchAll();

                            if (count($products) == 0) {
                                echo '<tr><td colspan="5" class="text-center">暂无产品数据</td></tr>';
                            } else {
                                foreach ($products as $p) {
                                    echo '<tr>';
                                    echo '<td>' . htmlspecialchars($p['name']) . '</td>';
                                    echo '<td>' . htmlspecialchars($p['category_name']) . '</td>';
                                    echo '<td>￥' . number_format($p['price'], 2) . '</td>';
                                    echo '<td>' . $p['sales_total'] . '</td>';
                                    echo '<td>';
                                    if ($p['status'] == 1) {
                                        echo '<span class="status-active">在售</span>';
                                    } elseif ($p['status'] == 2) {
                                        echo '<span class="status-inactive">停售</span>';
                                    } else {
                                        echo '<span class="status-pending">即将上市</span>';
                                    }
                                    echo '</td>';
                                    echo '</tr>';
                                }
                            }
                        } catch (PDOException $e) {
                            echo '<tr><td colspan="5" class="text-center">获取产品数据失败：' . $e->getMessage() . '</td></tr>';
                        }
                        ?>
                    </tbody>
                </table>
            </div>

            <h2>近期热销产品</h2>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>产品名称</th>
                            <th>订单数</th>
                            <th>销售数量</th>
                            <th>销售金额</th>
                            <th>均价</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        try {
                            // 修正：修复GROUP BY错误，对product_name使用MAX()聚合函数
                            $stmt = $pdo->query("
                                SELECT 
                                    MAX(oi.product_name) as product_name,
                                    COUNT(*) as order_count,
                                    SUM(oi.quantity) as total_quantity,
                                    SUM(oi.price * oi.quantity) as total_amount,
                                    SUM(oi.price * oi.quantity) / SUM(oi.quantity) as avg_price
                                FROM order_item oi
                                JOIN order_main om ON oi.order_id = om.id
                                WHERE om.create_time > DATE_SUB(NOW(), INTERVAL 7 DAY)
                                GROUP BY oi.product_id
                                ORDER BY total_quantity DESC
                                LIMIT 5
                            ");
                            $hot_products = $stmt->fetchAll();

                            if (count($hot_products) == 0) {
                                echo '<tr><td colspan="5" class="text-center">暂无近期销售数据</td></tr>';
                            } else {
                                foreach ($hot_products as $hp) {
                                    echo '<tr>';
                                    echo '<td>' . htmlspecialchars($hp['product_name']) . '</td>';
                                    echo '<td>' . $hp['order_count'] . '</td>';
                                    echo '<td>' . $hp['total_quantity'] . '</td>';
                                    echo '<td>￥' . number_format($hp['total_amount'], 2) . '</td>';
                                    echo '<td>￥' . number_format($hp['avg_price'], 2) . '</td>';
                                    echo '</tr>';
                                }
                            }
                        } catch (PDOException $e) {
                            echo '<tr><td colspan="5" class="text-center">获取热销产品数据失败：' . $e->getMessage() . '</td></tr>';
                        }
                        ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>