-- 1、用户与权限管理
-- 用户表
CREATE TABLE `sys_users` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '用户ID',
    `username` varchar(50) NOT NULL COMMENT '用户名',
    `password` varchar(255) NOT NULL COMMENT '密码',
    `mobile` varchar(20) DEFAULT NULL COMMENT '手机号',
    `role_id` int(11) NOT NULL DEFAULT 3 COMMENT '角色ID',
    `status` tinyint(1) NOT NULL DEFAULT '1' COMMENT '状态：1=启用，0=禁用',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_username` (`username`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '系统用户表';

-- 角色权限表
CREATE TABLE `sys_roles` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '角色ID',
    `role_name` varchar(50) NOT NULL COMMENT '角色名称',
    `permissions` text DEFAULT NULL COMMENT '权限(JSON格式)',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '角色权限表';

-- 操作日志表
CREATE TABLE `sys_logs` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '日志ID',
    `user_id` int(11) DEFAULT NULL COMMENT '操作用户ID',
    `username` varchar(50) DEFAULT NULL COMMENT '操作用户名',
    `operation` varchar(500) NOT NULL COMMENT '操作描述',
    `ip` varchar(50) DEFAULT NULL COMMENT '操作IP',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '操作日志表';

-- 数据备份表
CREATE TABLE `sys_backups` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '备份ID',
    `backup_name` varchar(100) NOT NULL COMMENT '备份名称',
    `backup_path` varchar(255) NOT NULL COMMENT '备份文件路径',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '数据备份表';

-- 初始化角色数据
INSERT INTO
    `sys_roles` (`id`, `role_name`, `permissions`)
VALUES
    (
        1,
        '系统管理员',
        '{"all": true, "system": true, "user": true, "role": true, "backup": true, "store": true, "employee": true, "inventory": true, "supplier": true, "purchase": true, "member": true, "marketing": true, "order": true, "product": true, "finance": true, "report": true, "statistics": true, "equipment": true}'
    ),
    (
        2,
        '店长',
        '{"store": {"view": true, "edit": true}, "employee": {"view": true, "add": true, "edit": true}, "inventory": true, "supplier": {"view": true}, "purchase": {"view": true, "add": true, "approve": true}, "member": true, "marketing": {"view": true, "add": true, "edit": true}, "order": true, "product": {"view": true, "price": true}, "finance": {"view": true, "daily": true}, "report": {"view": true, "store": true}, "statistics": {"view": true, "store": true}, "equipment": true}'
    ),
    (
        3,
        '店员',
        '{"order": {"view": true, "add": true, "process": true}, "product": {"view": true}, "member": {"view": true, "add": true}, "inventory": {"view": true}, "profile": true}'
    ),
    (
        4,
        '财务',
        '{"finance": true, "report": true, "statistics": true, "store": {"view": true}, "order": {"view": true}, "purchase": {"view": true, "verify": true}, "supplier": {"view": true}, "employee": {"view": true}, "profile": true}'
    );

-- 初始管理员账户，密码为admin的MD5哈希值
INSERT INTO
    `sys_users` (
        `username`,
        `password`,
        `mobile`,
        `role_id`,
        `status`
    )
VALUES
    (
        'admin',
        '21232f297a57a5a743894a0e4a801fc3',
        '13800138000',
        1,
        1
    );

-- --------------------------------------------------------
-- 2. 门店管理模块表结构（精简版）
-- --------------------------------------------------------

-- (1) 门店表
CREATE TABLE `store_info` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '门店ID',
    `store_name` varchar(100) NOT NULL COMMENT '门店名称',
    `address` varchar(255) DEFAULT NULL COMMENT '门店地址',
    `contact_phone` varchar(20) DEFAULT NULL COMMENT '联系电话',
    `business_hours` varchar(100) DEFAULT NULL COMMENT '营业时间',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=营业中，0=已关闭',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='门店信息表';

-- 门店初始数据
INSERT INTO `store_info` (`store_name`, `address`, `contact_phone`, `business_hours`, `status`) VALUES ('总店', '北京市朝阳区建国路88号', '010-88888888', '07:00-22:00', 1);

-- (2) 员工表
CREATE TABLE `emp_info` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '员工ID',
    `store_id` int(11) NOT NULL COMMENT '所属门店ID',
    `name` varchar(50) NOT NULL COMMENT '员工姓名',
    `phone` varchar(20) DEFAULT NULL COMMENT '联系电话',
    `position` varchar(50) DEFAULT NULL COMMENT '职位',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=在职，0=离职',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='员工信息表';

-- 员工初始数据
INSERT INTO `emp_info` (`store_id`, `name`, `phone`, `position`, `status`) VALUES (1, '张店长', '13900001111', '店长', 1);
INSERT INTO `emp_info` (`store_id`, `name`, `phone`, `position`, `status`) VALUES (1, '李店员', '13900001112', '店员', 1);

-- (3) 员工工作记录表（合并考勤和排班）
CREATE TABLE `emp_work` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `emp_id` int(11) NOT NULL COMMENT '员工ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `work_date` date NOT NULL COMMENT '工作日期',
    `start_time` time DEFAULT NULL COMMENT '开始时间',
    `end_time` time DEFAULT NULL COMMENT '结束时间',
    `work_type` tinyint(1) DEFAULT 1 COMMENT '类型：1=正常班次，2=加班',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=正常，2=迟到，3=早退，4=旷工',
    `remarks` varchar(255) DEFAULT NULL COMMENT '备注',
    PRIMARY KEY (`id`),
    KEY `idx_emp_date` (`emp_id`, `work_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='员工工作记录表';

-- 工作记录初始数据
INSERT INTO `emp_work` (`emp_id`, `store_id`, `work_date`, `start_time`, `end_time`, `work_type`, `status`) VALUES (1, 1, '2023-05-01', '08:00:00', '17:00:00', 1, 1);

-- (4) 设备表
CREATE TABLE `equip_info` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '设备ID',
    `store_id` int(11) NOT NULL COMMENT '所属门店ID',
    `name` varchar(100) NOT NULL COMMENT '设备名称',
    `type` varchar(50) NOT NULL COMMENT '设备类型',
    `purchase_date` date DEFAULT NULL COMMENT '购买日期',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=正常，2=维修中，3=已报废',
    PRIMARY KEY (`id`),
    KEY `idx_store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='设备信息表';

-- 设备初始数据
INSERT INTO `equip_info` (`store_id`, `name`, `type`, `purchase_date`, `status`) VALUES (1, '意式咖啡机', '咖啡机', '2023-01-15', 1);

-- (5) 设备维护记录表（包含维护记录和提醒）
CREATE TABLE `equip_maintain` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `equip_id` int(11) NOT NULL COMMENT '设备ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `maintain_date` date NOT NULL COMMENT '维护日期',
    `maintain_type` tinyint(1) NOT NULL COMMENT '类型：1=已完成维护，2=计划维护',
    `operator` varchar(50) DEFAULT NULL COMMENT '维护人员',
    `description` varchar(255) DEFAULT NULL COMMENT '维护描述',
    PRIMARY KEY (`id`),
    KEY `idx_equip_id` (`equip_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='设备维护记录表';

-- 维护记录初始数据
INSERT INTO `equip_maintain` (`equip_id`, `store_id`, `maintain_date`, `maintain_type`, `operator`, `description`) VALUES (1, 1, '2023-04-15', 1, '张店长', '日常清洗与保养');

-- --------------------------------------------------------
-- 3. 订单与销售管理模块表结构
-- --------------------------------------------------------

-- (1) 订单主表
CREATE TABLE `order_main` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '订单ID',
    `order_no` varchar(20) NOT NULL COMMENT '订单编号',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `order_type` tinyint(1) NOT NULL DEFAULT 1 COMMENT '订单类型：1=堂食，2=外带，3=外卖',
    `order_source` tinyint(1) NOT NULL DEFAULT 1 COMMENT '订单来源：1=店员下单，2=自助点单，3=扫码点单，4=外卖平台',
    `total_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '订单总金额',
    `discount_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '优惠金额',
    `pay_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '实付金额',
    `member_id` int(11) DEFAULT NULL COMMENT '会员ID',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '订单状态：1=待支付，2=待处理，3=制作中，4=已完成，5=已取消',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `finish_time` datetime DEFAULT NULL COMMENT '完成时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_order_no` (`order_no`),
    KEY `idx_store_id` (`store_id`),
    KEY `idx_member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='订单主表';

-- 订单主表初始数据
INSERT INTO `order_main` (`order_no`, `store_id`, `order_type`, `order_source`, `total_amount`, `pay_amount`, `status`, `create_time`) VALUES ('ORD20230501001', 1, 1, 1, 36.00, 36.00, 4, '2023-05-01 10:15:30');
INSERT INTO `order_main` (`order_no`, `store_id`, `order_type`, `order_source`, `total_amount`, `discount_amount`, `pay_amount`, `member_id`, `status`, `create_time`) VALUES ('ORD20230501002', 1, 2, 3, 45.00, 5.00, 40.00, 1, 3, '2023-05-01 11:30:25');

-- (2) 订单明细表
CREATE TABLE `order_item` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '明细ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `product_id` int(11) NOT NULL COMMENT '产品ID',
    `product_name` varchar(100) NOT NULL COMMENT '产品名称',
    `price` decimal(10,2) NOT NULL COMMENT '产品单价',
    `quantity` int(11) NOT NULL DEFAULT 1 COMMENT '数量',
    `subtotal` decimal(10,2) NOT NULL COMMENT '小计金额',
    `attributes` varchar(255) DEFAULT NULL COMMENT '产品属性(如：温度、甜度等)',
    PRIMARY KEY (`id`),
    KEY `idx_order_id` (`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='订单明细表';

-- 订单明细表初始数据
INSERT INTO `order_item` (`order_id`, `product_id`, `product_name`, `price`, `quantity`, `subtotal`, `attributes`) VALUES (1, 1, '美式咖啡', 18.00, 2, 36.00, '常温，无糖');
INSERT INTO `order_item` (`order_id`, `product_id`, `product_name`, `price`, `quantity`, `subtotal`, `attributes`) VALUES (2, 2, '拿铁咖啡', 22.00, 1, 22.00, '热，半糖');
INSERT INTO `order_item` (`order_id`, `product_id`, `product_name`, `price`, `quantity`, `subtotal`, `attributes`) VALUES (2, 3, '提拉米苏', 23.00, 1, 23.00, NULL);

-- (3) 支付记录表
CREATE TABLE `pay_record` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '支付ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `pay_no` varchar(32) DEFAULT NULL COMMENT '支付流水号',
    `pay_type` tinyint(1) NOT NULL COMMENT '支付方式：1=现金，2=微信，3=支付宝，4=银行卡，5=会员余额',
    `pay_amount` decimal(10,2) NOT NULL COMMENT '支付金额',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '支付状态：1=待支付，2=支付中，3=已支付，4=已退款',
    `pay_time` datetime DEFAULT NULL COMMENT '支付时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_order_id` (`order_id`),
    KEY `idx_pay_no` (`pay_no`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='支付记录表';

-- 支付记录表初始数据
INSERT INTO `pay_record` (`order_id`, `pay_no`, `pay_type`, `pay_amount`, `status`, `pay_time`) VALUES (1, 'P202305010001', 1, 36.00, 3, '2023-05-01 10:16:20');
INSERT INTO `pay_record` (`order_id`, `pay_no`, `pay_type`, `pay_amount`, `status`, `pay_time`) VALUES (2, 'P202305010002', 2, 40.00, 3, '2023-05-01 11:31:05');

-- (4) 订单状态记录表
CREATE TABLE `order_status` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `order_id` int(11) NOT NULL COMMENT '订单ID',
    `status` tinyint(1) NOT NULL COMMENT '状态：1=下单，2=支付，3=制作，4=完成，5=取消',
    `operator_id` int(11) DEFAULT NULL COMMENT '操作人ID',
    `operator_name` varchar(50) DEFAULT NULL COMMENT '操作人姓名',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_order_id` (`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='订单状态记录表';

-- 订单状态记录表初始数据
INSERT INTO `order_status` (`order_id`, `status`, `operator_id`, `operator_name`, `remark`) VALUES (1, 1, 2, '李店员', '顾客点单');
INSERT INTO `order_status` (`order_id`, `status`, `operator_id`, `operator_name`, `remark`) VALUES (1, 2, 2, '李店员', '现金支付');
INSERT INTO `order_status` (`order_id`, `status`, `operator_id`, `operator_name`, `remark`) VALUES (1, 3, 2, '李店员', '开始制作');
INSERT INTO `order_status` (`order_id`, `status`, `operator_id`, `operator_name`, `remark`) VALUES (1, 4, 2, '李店员', '已完成并送达');
INSERT INTO `order_status` (`order_id`, `status`, `operator_id`, `operator_name`, `remark`) VALUES (2, 1, NULL, '系统', '扫码点单');
INSERT INTO `order_status` (`order_id`, `status`, `operator_id`, `operator_name`, `remark`) VALUES (2, 2, NULL, '系统', '微信支付');
INSERT INTO `order_status` (`order_id`, `status`, `operator_id`, `operator_name`, `remark`) VALUES (2, 3, 2, '李店员', '开始制作');

-- (5) 外卖平台订单关联表
CREATE TABLE `order_takeout` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `order_id` int(11) NOT NULL COMMENT '系统订单ID',
    `platform` tinyint(1) NOT NULL COMMENT '平台：1=美团，2=饿了么，3=其他',
    `platform_order_no` varchar(50) NOT NULL COMMENT '平台订单号',
    `delivery_fee` decimal(10,2) DEFAULT 0.00 COMMENT '配送费',
    `rider_name` varchar(50) DEFAULT NULL COMMENT '骑手姓名',
    `rider_phone` varchar(20) DEFAULT NULL COMMENT '骑手电话',
    `delivery_time` datetime DEFAULT NULL COMMENT '预计送达时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_order_id` (`order_id`),
    KEY `idx_platform_order` (`platform`, `platform_order_no`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='外卖平台订单关联表';

-- 外卖平台订单关联表初始数据
INSERT INTO `order_takeout` (`order_id`, `platform`, `platform_order_no`, `delivery_fee`, `rider_name`, `rider_phone`, `delivery_time`) VALUES (2, 1, 'MT1234567890', 5.00, '王骑手', '13800138001', '2023-05-01 12:00:00');

-- --------------------------------------------------------
-- 4. 库存与供应链管理模块表结构（精简版）
-- --------------------------------------------------------

-- (1) 原料库存表
CREATE TABLE `inv_material` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '原料ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `name` varchar(100) NOT NULL COMMENT '原料名称',
    `category` varchar(50) NOT NULL COMMENT '类别',
    `unit` varchar(20) NOT NULL COMMENT '单位',
    `stock` decimal(10,2) NOT NULL DEFAULT 0 COMMENT '当前库存',
    `min_stock` decimal(10,2) NOT NULL DEFAULT 0 COMMENT '最低库存',
    `cost_price` decimal(10,2) DEFAULT 0 COMMENT '成本价',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=正常，0=停用',
    PRIMARY KEY (`id`),
    KEY `idx_store_id` (`store_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='原料库存表';

-- 原料库存表初始数据
INSERT INTO `inv_material` (`store_id`, `name`, `category`, `unit`, `stock`, `min_stock`, `cost_price`, `status`) VALUES (1, '哥伦比亚咖啡豆', '咖啡豆', '千克', 25.00, 10.00, 120.00, 1);
INSERT INTO `inv_material` (`store_id`, `name`, `category`, `unit`, `stock`, `min_stock`, `cost_price`, `status`) VALUES (1, '全脂牛奶', '奶制品', '升', 30.00, 15.00, 12.00, 1);

-- (2) 供应商表（合并供应商信息和报价）
CREATE TABLE `sup_info` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '供应商ID',
    `name` varchar(100) NOT NULL COMMENT '供应商名称',
    `contact` varchar(50) DEFAULT NULL COMMENT '联系人',
    `phone` varchar(20) DEFAULT NULL COMMENT '联系电话',
    `address` varchar(255) DEFAULT NULL COMMENT '地址',
    `category` varchar(100) DEFAULT NULL COMMENT '供应类别',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=正常，0=停用',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='供应商表';

-- 供应商表初始数据
INSERT INTO `sup_info` (`name`, `contact`, `phone`, `address`, `category`, `status`) VALUES ('优质咖啡豆供应商', '张经理', '13566778899', '北京市朝阳区建国路100号', '咖啡豆', 1);
INSERT INTO `sup_info` (`name`, `contact`, `phone`, `address`, `category`, `status`) VALUES ('鲜牛奶直供', '李经理', '13677889900', '北京市顺义区奶牛场路18号', '奶制品', 1);

-- (3) 采购订单表（合并订单和订单明细）
CREATE TABLE `pur_order` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '采购ID',
    `order_no` varchar(20) NOT NULL COMMENT '采购单号',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `supplier_id` int(11) NOT NULL COMMENT '供应商ID',
    `material_id` int(11) NOT NULL COMMENT '原料ID',
    `material_name` varchar(100) NOT NULL COMMENT '原料名称',
    `quantity` decimal(10,2) NOT NULL COMMENT '数量',
    `unit` varchar(20) NOT NULL COMMENT '单位',
    `price` decimal(10,2) NOT NULL COMMENT '单价',
    `amount` decimal(10,2) NOT NULL COMMENT '金额',
    `status` tinyint(1) NOT NULL DEFAULT 1 COMMENT '状态：1=待审核，2=已审核，3=已入库，4=已取消',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_order_no` (`order_no`),
    KEY `idx_store_id` (`store_id`),
    KEY `idx_supplier_id` (`supplier_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='采购订单表';

-- 采购订单表初始数据
INSERT INTO `pur_order` (`order_no`, `store_id`, `supplier_id`, `material_id`, `material_name`, `quantity`, `unit`, `price`, `amount`, `status`) VALUES ('PUR20230510001', 1, 1, 1, '哥伦比亚咖啡豆', 10.00, '千克', 120.00, 1200.00, 2);
INSERT INTO `pur_order` (`order_no`, `store_id`, `supplier_id`, `material_id`, `material_name`, `quantity`, `unit`, `price`, `amount`, `status`) VALUES ('PUR20230515001', 1, 2, 2, '全脂牛奶', 30.00, '升', 12.00, 360.00, 1);

-- (4) 库存变动记录表（合并入库、消耗、报废记录）
CREATE TABLE `inv_record` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `material_id` int(11) NOT NULL COMMENT '原料ID',
    `record_type` tinyint(1) NOT NULL COMMENT '记录类型：1=入库，2=订单消耗，3=报废，4=盘点调整',
    `quantity` decimal(10,2) NOT NULL COMMENT '数量',
    `order_id` int(11) DEFAULT NULL COMMENT '关联订单ID',
    `purchase_id` int(11) DEFAULT NULL COMMENT '关联采购ID',
    `batch_no` varchar(50) DEFAULT NULL COMMENT '批次号',
    `expiry_date` date DEFAULT NULL COMMENT '过期日期',
    `operator` varchar(50) DEFAULT NULL COMMENT '操作人',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_store_material` (`store_id`, `material_id`),
    KEY `idx_record_type` (`record_type`),
    KEY `idx_order_id` (`order_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='库存变动记录表';

-- 库存变动记录表初始数据
INSERT INTO `inv_record` (`store_id`, `material_id`, `record_type`, `quantity`, `purchase_id`, `batch_no`, `expiry_date`, `operator`) VALUES (1, 1, 1, 10.00, 1, 'B20230512001', '2023-11-01', '张店长');
INSERT INTO `inv_record` (`store_id`, `material_id`, `record_type`, `quantity`, `order_id`, `operator`) VALUES (1, 1, 2, 0.05, 1, '李店员');
INSERT INTO `inv_record` (`store_id`, `material_id`, `record_type`, `quantity`, `order_id`, `operator`) VALUES (1, 2, 2, 0.20, 2, '李店员');
INSERT INTO `inv_record` (`store_id`, `material_id`, `record_type`, `quantity`, `operator`) VALUES (1, 2, 3, 2.00, '张店长');

-- --------------------------------------------------------
-- 5. 会员与营销管理模块表结构（精简版）
-- --------------------------------------------------------

-- (1) 会员表（合并会员信息和账户）
CREATE TABLE `mem_info` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '会员ID',
    `member_no` varchar(20) NOT NULL COMMENT '会员编号',
    `name` varchar(50) DEFAULT NULL COMMENT '会员姓名',
    `phone` varchar(20) NOT NULL COMMENT '手机号码',
    `birthday` date DEFAULT NULL COMMENT '生日',
    `level` tinyint(1) DEFAULT 1 COMMENT '会员等级：1=普通，2=银卡，3=金卡，4=黑卡',
    `points` int(11) NOT NULL DEFAULT 0 COMMENT '积分余额',
    `balance` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '账户余额',
    `total_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '累计消费',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=正常，0=禁用',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_phone` (`phone`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='会员表';

-- 会员表初始数据
INSERT INTO `mem_info` (`member_no`, `name`, `phone`, `birthday`, `level`, `points`, `balance`, `total_amount`) VALUES ('M20230001', '张三', '13900001234', '1990-01-15', 2, 520, 300.00, 2360.00);
INSERT INTO `mem_info` (`member_no`, `name`, `phone`, `birthday`, `level`, `points`, `balance`, `total_amount`) VALUES ('M20230002', '李四', '13900005678', '1985-08-22', 1, 80, 0.00, 160.00);

-- (2) 会员交易记录表
CREATE TABLE `mem_record` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '记录ID',
    `member_id` int(11) NOT NULL COMMENT '会员ID',
    `type` tinyint(1) NOT NULL COMMENT '类型：1=积分增加，2=积分消费，3=余额充值，4=余额消费',
    `amount` decimal(10,2) NOT NULL COMMENT '交易金额/积分',
    `order_id` int(11) DEFAULT NULL COMMENT '关联订单ID',
    `remark` varchar(255) DEFAULT NULL COMMENT '备注',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='会员交易记录表';

-- 会员交易记录表初始数据
INSERT INTO `mem_record` (`member_id`, `type`, `amount`, `order_id`, `remark`) VALUES (1, 1, 50, 2, '消费赠送积分');
INSERT INTO `mem_record` (`member_id`, `type`, `amount`, `remark`) VALUES (1, 3, 300.00, '会员充值');

-- (3) 优惠券表（合并优惠券定义和会员优惠券）
CREATE TABLE `mkt_coupon` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '优惠券ID',
    `coupon_name` varchar(100) NOT NULL COMMENT '优惠券名称',
    `coupon_type` tinyint(1) NOT NULL COMMENT '类型：1=折扣券，2=满减券',
    `value` decimal(10,2) NOT NULL COMMENT '面值/折扣',
    `min_amount` decimal(10,2) DEFAULT 0 COMMENT '最低消费金额',
    `member_id` int(11) DEFAULT NULL COMMENT '会员ID(NULL表示优惠券模板)',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=可用，2=已使用，3=已过期，0=已禁用',
    `start_time` datetime NOT NULL COMMENT '生效时间',
    `end_time` datetime NOT NULL COMMENT '失效时间',
    `order_id` int(11) DEFAULT NULL COMMENT '使用订单ID',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_member_id` (`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='优惠券表';

-- 优惠券表初始数据（模板）
INSERT INTO `mkt_coupon` (`coupon_name`, `coupon_type`, `value`, `min_amount`, `start_time`, `end_time`, `status`) VALUES ('新人8.5折券', 1, 8.5, 0, '2023-05-01 00:00:00', '2023-12-31 23:59:59', 1);
INSERT INTO `mkt_coupon` (`coupon_name`, `coupon_type`, `value`, `min_amount`, `member_id`, `status`, `start_time`, `end_time`, `order_id`) VALUES ('满50减10券', 2, 10.00, 50.00, 1, 1, '2023-05-01 00:00:00', '2023-06-30 23:59:59', NULL);

-- (4) 营销活动表
CREATE TABLE `mkt_activity` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '活动ID',
    `name` varchar(100) NOT NULL COMMENT '活动名称',
    `type` tinyint(1) NOT NULL COMMENT '类型：1=折扣，2=满减，3=赠品，4=积分翻倍',
    `rule` varchar(255) NOT NULL COMMENT '活动规则',
    `start_time` datetime NOT NULL COMMENT '开始时间',
    `end_time` datetime NOT NULL COMMENT '结束时间',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=正常，0=已取消',
    PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='营销活动表';

-- 营销活动表初始数据（更新为2024到2030年的日期）
INSERT INTO `mkt_activity` (`name`, `type`, `rule`, `start_time`, `end_time`, `status`) VALUES ('五一特惠', 1, '五一期间全场咖啡8.8折', '2024-05-01 00:00:00', '2030-05-05 23:59:59', 1);
INSERT INTO `mkt_activity` (`name`, `type`, `rule`, `start_time`, `end_time`, `status`) VALUES ('会员日活动', 4, '每月15日会员消费积分翻倍', '2024-05-15 00:00:00', '2030-05-15 23:59:59', 1);

-- --------------------------------------------------------
-- 6. 财务与结算管理模块表结构
-- --------------------------------------------------------

-- (1) 日销售统计表
CREATE TABLE `fin_daily` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `sale_date` date NOT NULL COMMENT '销售日期',
    `total_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '销售总额',
    `order_count` int(11) NOT NULL DEFAULT 0 COMMENT '订单数量',
    `customer_count` int(11) NOT NULL DEFAULT 0 COMMENT '客户数量',
    `average_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '客单价',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=正常，0=作废',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_store_date` (`store_id`, `sale_date`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='日销售统计表';

-- 日销售统计表初始数据
INSERT INTO `fin_daily` (`store_id`, `sale_date`, `total_amount`, `order_count`, `customer_count`, `average_amount`) VALUES (1, '2023-05-01', 2580.00, 86, 78, 33.08);
INSERT INTO `fin_daily` (`store_id`, `sale_date`, `total_amount`, `order_count`, `customer_count`, `average_amount`) VALUES (1, '2023-05-02', 2320.50, 75, 70, 33.15);

-- (2) 收支记录表
CREATE TABLE `fin_transaction` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '交易ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `trans_type` tinyint(1) NOT NULL COMMENT '类型：1=销售收入，2=进货支出，3=工资支出，4=设备维护支出，5=其他收入，6=其他支出',
    `amount` decimal(10,2) NOT NULL COMMENT '金额',
    `trans_date` date NOT NULL COMMENT '交易日期',
    `related_id` int(11) DEFAULT NULL COMMENT '关联ID（如订单ID、采购ID等）',
    `description` varchar(255) DEFAULT NULL COMMENT '交易描述',
    `operator` varchar(50) DEFAULT NULL COMMENT '操作人',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    KEY `idx_store_date` (`store_id`, `trans_date`),
    KEY `idx_trans_type` (`trans_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='收支记录表';

-- 收支记录表初始数据
INSERT INTO `fin_transaction` (`store_id`, `trans_type`, `amount`, `trans_date`, `related_id`, `description`, `operator`) VALUES (1, 1, 2580.00, '2023-05-01', NULL, '5月1日销售收入', '张店长');
INSERT INTO `fin_transaction` (`store_id`, `trans_type`, `amount`, `trans_date`, `related_id`, `description`, `operator`) VALUES (1, 2, 1200.00, '2023-05-10', 1, '咖啡豆采购支出', '张店长');

-- (3) 利润分析表
CREATE TABLE `fin_profit` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `period` varchar(20) NOT NULL COMMENT '统计周期(如：2023-05, 2023-Q2)',
    `total_revenue` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '总收入',
    `total_cost` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '总成本',
    `material_cost` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '原料成本',
    `labor_cost` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '人工成本',
    `other_cost` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '其他成本',
    `gross_profit` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '毛利润',
    `gross_profit_rate` decimal(5,2) NOT NULL DEFAULT 0.00 COMMENT '毛利率(%)',
    `net_profit` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '净利润',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_store_period` (`store_id`, `period`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='利润分析表';

-- 利润分析表初始数据
INSERT INTO `fin_profit` (`store_id`, `period`, `total_revenue`, `total_cost`, `material_cost`, `labor_cost`, `other_cost`, `gross_profit`, `gross_profit_rate`, `net_profit`) VALUES (1, '2023-04', 68500.00, 41100.00, 23600.00, 15000.00, 2500.00, 44900.00, 65.55, 27400.00);
INSERT INTO `fin_profit` (`store_id`, `period`, `total_revenue`, `total_cost`, `material_cost`, `labor_cost`, `other_cost`, `gross_profit`, `gross_profit_rate`, `net_profit`) VALUES (1, '2023-05', 72300.00, 42800.00, 24500.00, 15800.00, 2500.00, 47800.00, 66.11, 29500.00);

-- (4) 员工薪资表
CREATE TABLE `fin_salary` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `emp_id` int(11) NOT NULL COMMENT '员工ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `salary_month` varchar(7) NOT NULL COMMENT '工资月份(格式：2023-05)',
    `base_salary` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '基本工资',
    `commission` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '提成',
    `bonus` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '奖金',
    `deduction` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '扣款',
    `total_salary` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '实发工资',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=未发放，2=已发放',
    `payment_time` datetime DEFAULT NULL COMMENT '发放时间',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_emp_month` (`emp_id`, `salary_month`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='员工薪资表';

-- 员工薪资表初始数据
INSERT INTO `fin_salary` (`emp_id`, `store_id`, `salary_month`, `base_salary`, `commission`, `bonus`, `deduction`, `total_salary`, `status`) VALUES (1, 1, '2023-04', 8000.00, 1200.00, 500.00, 0.00, 9700.00, 2);
INSERT INTO `fin_salary` (`emp_id`, `store_id`, `salary_month`, `base_salary`, `commission`, `bonus`, `deduction`, `total_salary`, `status`) VALUES (2, 1, '2023-04', 5000.00, 800.00, 300.00, 200.00, 5900.00, 2);

-- --------------------------------------------------------
-- 7. 数据分析与报表模块表结构
-- --------------------------------------------------------

-- (1) 销售数据分析表
CREATE TABLE `rpt_sales` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `product_id` int(11) NOT NULL COMMENT '产品ID',
    `product_name` varchar(100) NOT NULL COMMENT '产品名称',
    `category` varchar(50) NOT NULL COMMENT '产品类别',
    `period` varchar(20) NOT NULL COMMENT '统计周期(日:YYYY-MM-DD,月:YYYY-MM)',
    `sale_count` int(11) NOT NULL DEFAULT 0 COMMENT '销售数量',
    `sale_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '销售金额',
    `rank` int(11) DEFAULT NULL COMMENT '排名',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_store_prod_period` (`store_id`, `product_id`, `period`),
    KEY `idx_category` (`category`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='销售数据分析表';

-- 销售数据分析表初始数据
INSERT INTO `rpt_sales` (`store_id`, `product_id`, `product_name`, `category`, `period`, `sale_count`, `sale_amount`, `rank`) VALUES (1, 2, '拿铁咖啡', '咖啡', '2023-05', 568, 12496.00, 1);
INSERT INTO `rpt_sales` (`store_id`, `product_id`, `product_name`, `category`, `period`, `sale_count`, `sale_amount`, `rank`) VALUES (1, 1, '美式咖啡', '咖啡', '2023-05', 486, 8748.00, 2);

-- (2) 会员消费分析表
CREATE TABLE `rpt_member` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `member_id` int(11) NOT NULL COMMENT '会员ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `period` varchar(20) NOT NULL COMMENT '统计周期(YYYY-MM)',
    `visit_count` int(11) NOT NULL DEFAULT 0 COMMENT '到店次数',
    `total_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '消费总额',
    `avg_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '平均客单价',
    `fav_product_id` int(11) DEFAULT NULL COMMENT '最常购买产品ID',
    `fav_product_name` varchar(100) DEFAULT NULL COMMENT '最常购买产品名称',
    `fav_category` varchar(50) DEFAULT NULL COMMENT '最常购买品类',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_member_period` (`member_id`, `period`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='会员消费分析表';

-- 会员消费分析表初始数据
INSERT INTO `rpt_member` (`member_id`, `store_id`, `period`, `visit_count`, `total_amount`, `avg_amount`, `fav_product_id`, `fav_product_name`, `fav_category`) VALUES (1, 1, '2023-05', 8, 420.00, 52.50, 2, '拿铁咖啡', '咖啡');
INSERT INTO `rpt_member` (`member_id`, `store_id`, `period`, `visit_count`, `total_amount`, `avg_amount`, `fav_product_id`, `fav_product_name`, `fav_category`) VALUES (2, 1, '2023-05', 3, 160.00, 53.33, 1, '美式咖啡', '咖啡');

-- (3) 库存周转分析表
CREATE TABLE `rpt_inventory` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `material_id` int(11) NOT NULL COMMENT '原料ID',
    `material_name` varchar(100) NOT NULL COMMENT '原料名称',
    `period` varchar(20) NOT NULL COMMENT '统计周期(YYYY-MM)',
    `begin_stock` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '期初库存',
    `end_stock` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '期末库存',
    `in_qty` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '入库数量',
    `out_qty` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '消耗数量',
    `turnover_days` decimal(5,1) DEFAULT NULL COMMENT '周转天数',
    `consumption_rate` decimal(5,2) DEFAULT NULL COMMENT '日均消耗率',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_store_material_period` (`store_id`, `material_id`, `period`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='库存周转分析表';

-- 库存周转分析表初始数据
INSERT INTO `rpt_inventory` (`store_id`, `material_id`, `material_name`, `period`, `begin_stock`, `end_stock`, `in_qty`, `out_qty`, `turnover_days`, `consumption_rate`) VALUES (1, 1, '哥伦比亚咖啡豆', '2023-05', 20.00, 25.00, 10.00, 5.00, 150.0, 0.16);
INSERT INTO `rpt_inventory` (`store_id`, `material_id`, `material_name`, `period`, `begin_stock`, `end_stock`, `in_qty`, `out_qty`, `turnover_days`, `consumption_rate`) VALUES (1, 2, '全脂牛奶', '2023-05', 25.00, 30.00, 30.00, 25.00, 36.0, 0.81);

-- (4) 运营KPI统计表
CREATE TABLE `rpt_kpi` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
    `store_id` int(11) NOT NULL COMMENT '门店ID',
    `period` varchar(20) NOT NULL COMMENT '统计周期(YYYY-MM)',
    `order_count` int(11) NOT NULL DEFAULT 0 COMMENT '订单数',
    `customer_count` int(11) NOT NULL DEFAULT 0 COMMENT '客流量',
    `revenue` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '营业额',
    `revenue_growth` decimal(5,2) DEFAULT NULL COMMENT '营收增长率(%)',
    `gross_profit` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '毛利润',
    `gross_profit_rate` decimal(5,2) NOT NULL DEFAULT 0.00 COMMENT '毛利率(%)',
    `new_member_count` int(11) NOT NULL DEFAULT 0 COMMENT '新增会员数',
    `member_amount` decimal(10,2) NOT NULL DEFAULT 0.00 COMMENT '会员消费额',
    `member_ratio` decimal(5,2) NOT NULL DEFAULT 0.00 COMMENT '会员消费占比(%)',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_store_period` (`store_id`, `period`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='运营KPI统计表';

-- 运营KPI统计表初始数据
INSERT INTO `rpt_kpi` (`store_id`, `period`, `order_count`, `customer_count`, `revenue`, `revenue_growth`, `gross_profit`, `gross_profit_rate`, `new_member_count`, `member_amount`, `member_ratio`) VALUES (1, '2023-04', 2102, 1876, 68500.00, 5.23, 44900.00, 65.55, 32, 42800.00, 62.48);
INSERT INTO `rpt_kpi` (`store_id`, `period`, `order_count`, `customer_count`, `revenue`, `revenue_growth`, `gross_profit`, `gross_profit_rate`, `new_member_count`, `member_amount`, `member_ratio`) VALUES (1, '2023-05', 2246, 2010, 72300.00, 5.55, 47800.00, 66.11, 28, 45600.00, 63.07);

-- --------------------------------------------------------
-- 8. 产品管理模块表结构
-- --------------------------------------------------------

-- 产品表（product_items）
CREATE TABLE `product_items` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '产品ID',
    `product_code` varchar(20) NOT NULL COMMENT '产品编码',
    `name` varchar(100) NOT NULL COMMENT '产品名称',
    `category` int(11) NOT NULL DEFAULT 1 COMMENT '分类ID',
    `description` varchar(255) DEFAULT NULL COMMENT '产品描述',
    `price` decimal(10, 2) NOT NULL DEFAULT 0.00 COMMENT '标准价格',
    `cost` decimal(10, 2) DEFAULT 0.00 COMMENT '成本价',
    `unit` varchar(20) DEFAULT NULL COMMENT '单位',
    `image` varchar(255) DEFAULT NULL COMMENT '产品图片',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=在售，2=停售，3=即将上市',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`),
    UNIQUE KEY `idx_product_code` (`product_code`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '产品表';

-- 产品分类表
CREATE TABLE `product_category` (
    `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '分类ID',
    `name` varchar(50) NOT NULL COMMENT '分类名称',
    `parent_id` int(11) DEFAULT 0 COMMENT '父分类ID',
    `sort_order` int(11) DEFAULT 0 COMMENT '排序',
    `status` tinyint(1) DEFAULT 1 COMMENT '状态：1=启用，0=禁用',
    `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    PRIMARY KEY (`id`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '产品分类表';

-- 初始产品分类数据
INSERT INTO
    `product_category` (`id`, `name`, `parent_id`, `sort_order`)
VALUES
    (1, '咖啡', 0, 1),
    (2, '茶饮', 0, 2),
    (3, '甜点', 0, 3),
    (4, '零食', 0, 4),
    (5, '浓缩咖啡', 1, 1),
    (6, '手冲咖啡', 1, 2),
    (7, '特调咖啡', 1, 3);

-- 初始产品数据
INSERT INTO
    `product_items` (
        `product_code`,
        `name`,
        `category`,
        `description`,
        `price`,
        `cost`,
        `unit`,
        `status`
    )
VALUES
    (
        'COFFEE001',
        '美式咖啡',
        1,
        '清淡醇香的美式咖啡',
        18.00,
        5.00,
        '杯',
        1
    ),
    (
        'COFFEE002',
        '拿铁咖啡',
        1,
        '香浓丝滑的拿铁咖啡',
        22.00,
        7.50,
        '杯',
        1
    ),
    (
        'COFFEE003',
        '卡布奇诺',
        1,
        '奶泡丰富的意式经典',
        23.00,
        7.80,
        '杯',
        1
    ),
    (
        'COFFEE004',
        '摩卡咖啡',
        1,
        '巧克力风味咖啡',
        25.00,
        9.00,
        '杯',
        1
    ),
    (
        'DESSERT001',
        '提拉米苏',
        3,
        '意大利经典甜点',
        28.00,
        12.00,
        '块',
        1
    ),
    (
        'DESSERT002',
        '芝士蛋糕',
        3,
        '醇香浓郁芝士蛋糕',
        26.00,
        10.00,
        '块',
        1
    );