<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('store');

// 记录访问日志
record_log('访问门店信息管理页面');

// 门店ID处理
$store_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 更新门店信息
    if ($_POST['action'] == 'update') {
        $store_id = isset($_POST['store_id']) ? intval($_POST['store_id']) : 0;
        $store_name = isset($_POST['store_name']) ? trim($_POST['store_name']) : '';
        $address = isset($_POST['address']) ? trim($_POST['address']) : '';
        $contact_phone = isset($_POST['contact_phone']) ? trim($_POST['contact_phone']) : '';
        $business_hours = isset($_POST['business_hours']) ? trim($_POST['business_hours']) : '';
        $status = isset($_POST['status']) ? intval($_POST['status']) : 1;

        if ($store_id <= 0 || empty($store_name)) {
            $error = '请填写完整门店信息！';
        } else {
            try {
                // 检查门店名称是否已被其他门店使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM store_info WHERE store_name = ? AND id != ?");
                $stmt->execute([$store_name, $store_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '门店名称已被其他门店使用！';
                } else {
                    // 更新门店信息
                    $stmt = $pdo->prepare("UPDATE store_info SET store_name = ?, address = ?, contact_phone = ?, business_hours = ?, status = ? WHERE id = ?");
                    $result = $stmt->execute([$store_name, $address, $contact_phone, $business_hours, $status, $store_id]);

                    if ($result) {
                        record_log("更新门店信息：{$store_name}");
                        $success = '门店信息更新成功！';
                    } else {
                        $error = '门店信息更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 获取所有门店列表（用于下拉选择）
try {
    $stmt = $pdo->query("SELECT id, store_name FROM store_info ORDER BY id DESC");
    $stores = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取门店列表失败：' . $e->getMessage();
    $stores = [];
}

// 获取当前选择的门店详细信息
$current_store = null;
if ($store_id > 0) {
    try {
        $stmt = $pdo->prepare("SELECT * FROM store_info WHERE id = ?");
        $stmt->execute([$store_id]);
        $current_store = $stmt->fetch();

        if (!$current_store) {
            $error = '门店不存在！';
        }
    } catch (PDOException $e) {
        $error = '获取门店信息失败：' . $e->getMessage();
    }
}

// 获取门店员工信息
$employees = [];
if ($store_id > 0) {
    try {
        $stmt = $pdo->prepare("SELECT * FROM emp_info WHERE store_id = ? ORDER BY id DESC");
        $stmt->execute([$store_id]);
        $employees = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取员工信息失败：' . $e->getMessage();
    }
}

// 获取门店设备信息
$equipment = [];
if ($store_id > 0) {
    try {
        $stmt = $pdo->prepare("SELECT * FROM equip_info WHERE store_id = ? ORDER BY id DESC");
        $stmt->execute([$store_id]);
        $equipment = $stmt->fetchAll();
    } catch (PDOException $e) {
        $error = '获取设备信息失败：' . $e->getMessage();
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>门店信息管理</h2>
            <div class="breadcrumb">
                <a href="index.php">门店管理</a> &gt; 门店信息管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <!-- 门店选择表单 -->
            <div class="form-container">
                <h3>选择门店</h3>
                <form method="get" action="">
                    <div class="form-group">
                        <label for="id">选择门店：</label>
                        <select id="id" name="id" onchange="this.form.submit()">
                            <option value="">-- 请选择门店 --</option>
                            <?php foreach ($stores as $store): ?>
                                <option value="<?php echo $store['id']; ?>" <?php echo ($store_id == $store['id']) ? 'selected' : ''; ?>>
                                    <?php echo htmlspecialchars($store['store_name']); ?>
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                </form>
            </div>

            <?php if ($current_store): ?>
                <!-- 门店详细信息 -->
                <div class="form-container">
                    <h3>门店详细信息</h3>
                    <form method="post" action="">
                        <input type="hidden" name="action" value="update">
                        <input type="hidden" name="store_id" value="<?php echo $current_store['id']; ?>">

                        <div class="form-group">
                            <label for="store_name">门店名称：</label>
                            <input type="text" id="store_name" name="store_name" value="<?php echo htmlspecialchars($current_store['store_name']); ?>" required>
                        </div>

                        <div class="form-group">
                            <label for="address">门店地址：</label>
                            <input type="text" id="address" name="address" value="<?php echo htmlspecialchars($current_store['address'] ?: ''); ?>">
                        </div>

                        <div class="form-group">
                            <label for="contact_phone">联系电话：</label>
                            <input type="text" id="contact_phone" name="contact_phone" value="<?php echo htmlspecialchars($current_store['contact_phone'] ?: ''); ?>">
                        </div>

                        <div class="form-group">
                            <label for="business_hours">营业时间：</label>
                            <input type="text" id="business_hours" name="business_hours" value="<?php echo htmlspecialchars($current_store['business_hours'] ?: ''); ?>" placeholder="例如: 07:00-22:00">
                        </div>

                        <div class="form-group">
                            <label for="status">状态：</label>
                            <select id="status" name="status">
                                <option value="1" <?php echo ($current_store['status'] == 1) ? 'selected' : ''; ?>>营业中</option>
                                <option value="0" <?php echo ($current_store['status'] == 0) ? 'selected' : ''; ?>>已关闭</option>
                            </select>
                        </div>

                        <div class="form-actions">
                            <button type="submit" class="btn btn-success">保存修改</button>
                        </div>
                    </form>
                </div>

                <!-- 门店员工信息概览 -->
                <div class="table-container">
                    <h3>门店员工信息</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>姓名</th>
                                <th>职位</th>
                                <th>联系电话</th>
                                <th>状态</th>
                                <th>入职时间</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($employees)): ?>
                                <tr>
                                    <td colspan="6" class="text-center">暂无员工数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($employees as $emp): ?>
                                    <tr>
                                        <td><?php echo $emp['id']; ?></td>
                                        <td><?php echo htmlspecialchars($emp['name']); ?></td>
                                        <td><?php echo htmlspecialchars($emp['position'] ?: '-'); ?></td>
                                        <td><?php echo htmlspecialchars($emp['phone'] ?: '-'); ?></td>
                                        <td>
                                            <?php
                                            if ($emp['status'] == 1) echo '<span class="status-active">在职</span>';
                                            else echo '<span class="status-inactive">离职</span>';
                                            ?>
                                        </td>
                                        <td><?php echo $emp['create_time']; ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                    <div style="text-align: right; margin-top: 10px;">
                        <a href="employee.php" class="btn btn-primary">员工管理</a>
                    </div>
                </div>

                <!-- 门店设备信息概览 -->
                <div class="table-container">
                    <h3>门店设备信息</h3>
                    <table class="data-table">
                        <thead>
                            <tr>
                                <th>ID</th>
                                <th>设备名称</th>
                                <th>设备类型</th>
                                <th>购买日期</th>
                                <th>状态</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($equipment)): ?>
                                <tr>
                                    <td colspan="5" class="text-center">暂无设备数据</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($equipment as $equip): ?>
                                    <tr>
                                        <td><?php echo $equip['id']; ?></td>
                                        <td><?php echo htmlspecialchars($equip['name']); ?></td>
                                        <td><?php echo htmlspecialchars($equip['type'] ?: '-'); ?></td>
                                        <td><?php echo $equip['purchase_date'] ?: '-'; ?></td>
                                        <td>
                                            <?php
                                            if ($equip['status'] == 1) echo '<span class="status-active">正常</span>';
                                            elseif ($equip['status'] == 2) echo '<span style="color: orange;">维修中</span>';
                                            else echo '<span class="status-inactive">已报废</span>';
                                            ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                    <div style="text-align: right; margin-top: 10px;">
                        <a href="equipment.php" class="btn btn-primary">设备管理</a>
                    </div>
                </div>
            <?php else: ?>
                <div class="alert alert-danger">请先选择一个门店进行管理</div>
            <?php endif; ?>
        </div>
    </div>
</body>

</html>