<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('system_role');

// 记录访问日志
record_log('访问角色权限管理页面');

// 定义系统所有可用权限
$all_permissions = [
    'system' => [
        'view' => '系统设置-查看',
        'user' => '系统设置-用户管理',
        'role' => '系统设置-角色管理',
        'log' => '系统设置-日志查看',
        'backup' => '系统设置-数据备份'
    ],
    'store' => [
        'view' => '门店管理-查看',
        'add' => '门店管理-添加',
        'edit' => '门店管理-编辑',
        'delete' => '门店管理-删除',
        'sync' => '门店管理-数据同步'
    ],
    'employee' => [
        'view' => '员工管理-查看',
        'add' => '员工管理-添加',
        'edit' => '员工管理-编辑',
        'delete' => '员工管理-删除',
        'attendance' => '员工管理-考勤管理',
        'schedule' => '员工管理-排班管理',
        'performance' => '员工管理-绩效统计'
    ],
    'equipment' => [
        'view' => '设备管理-查看',
        'add' => '设备管理-添加',
        'edit' => '设备管理-编辑',
        'delete' => '设备管理-删除',
        'maintenance' => '设备管理-维护记录',
        'reminder' => '设备管理-维护提醒'
    ],
    'order' => [
        'view' => '订单管理-查看',
        'add' => '订单管理-添加',
        'edit' => '订单管理-编辑',
        'delete' => '订单管理-删除',
        'process' => '订单管理-订单处理',
        'takeaway' => '订单管理-外带管理',
        'delivery' => '订单管理-外卖管理',
        'payment' => '订单管理-支付管理',
        'invoice' => '订单管理-发票管理'
    ],
    'product' => [
        'view' => '产品管理-查看',
        'add' => '产品管理-添加',
        'edit' => '产品管理-编辑',
        'delete' => '产品管理-删除',
        'category' => '产品管理-分类管理',
        'price' => '产品管理-价格管理'
    ],
    'inventory' => [
        'view' => '库存管理-查看',
        'add' => '库存管理-入库',
        'out' => '库存管理-出库',
        'check' => '库存管理-盘点',
        'alert' => '库存管理-库存报警',
        'waste' => '库存管理-报废管理'
    ],
    'supplier' => [
        'view' => '供应商管理-查看',
        'add' => '供应商管理-添加',
        'edit' => '供应商管理-编辑',
        'delete' => '供应商管理-删除',
        'price' => '供应商管理-报价记录'
    ],
    'purchase' => [
        'view' => '采购管理-查看',
        'add' => '采购管理-添加',
        'edit' => '采购管理-编辑',
        'delete' => '采购管理-删除',
        'approve' => '采购管理-审核',
        'verify' => '采购管理-验收入库'
    ],
    'member' => [
        'view' => '会员管理-查看',
        'add' => '会员管理-添加',
        'edit' => '会员管理-编辑',
        'delete' => '会员管理-删除',
        'level' => '会员管理-等级设置',
        'points' => '会员管理-积分管理',
        'card' => '会员管理-储值卡'
    ],
    'marketing' => [
        'view' => '营销管理-查看',
        'activity' => '营销管理-活动管理',
        'coupon' => '营销管理-优惠券',
        'discount' => '营销管理-折扣管理',
        'sms' => '营销管理-短信营销',
        'wechat' => '营销管理-微信营销'
    ],
    'finance' => [
        'view' => '财务管理-查看',
        'daily' => '财务管理-日结算',
        'income' => '财务管理-收入管理',
        'expense' => '财务管理-支出管理',
        'salary' => '财务管理-工资管理',
        'statement' => '财务管理-对账单'
    ],
    'report' => [
        'view' => '数据报表-查看',
        'sales' => '数据报表-销售报表',
        'store' => '数据报表-门店报表',
        'product' => '数据报表-产品报表',
        'member' => '数据报表-会员报表',
        'finance' => '数据报表-财务报表'
    ],
    'statistics' => [
        'view' => '数据分析-查看',
        'sales' => '数据分析-销售分析',
        'customer' => '数据分析-顾客分析',
        'inventory' => '数据分析-库存分析',
        'kpi' => '数据分析-KPI统计'
    ],
    'profile' => [
        'view' => '个人信息-查看',
        'edit' => '个人信息-编辑'
    ],
    'all' => '所有权限'
];

// 处理表单提交
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['action'])) {
    // 添加角色
    if ($_POST['action'] == 'add') {
        $role_name = isset($_POST['role_name']) ? trim($_POST['role_name']) : '';
        $permissions = isset($_POST['permissions']) ? $_POST['permissions'] : [];

        if (empty($role_name)) {
            $error = '角色名称不能为空！';
        } else {
            try {
                // 检查角色名是否已存在
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_roles WHERE role_name = ?");
                $stmt->execute([$role_name]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '角色名称已存在！';
                } else {
                    // 权限处理
                    $permissions_json = json_encode(process_permissions($permissions));

                    // 添加角色
                    $stmt = $pdo->prepare("INSERT INTO sys_roles (role_name, permissions) VALUES (?, ?)");
                    $result = $stmt->execute([$role_name, $permissions_json]);

                    if ($result) {
                        record_log("添加角色：{$role_name}");
                        $success = '角色添加成功！';
                    } else {
                        $error = '角色添加失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 编辑角色
    elseif ($_POST['action'] == 'edit') {
        $role_id = isset($_POST['role_id']) ? intval($_POST['role_id']) : 0;
        $role_name = isset($_POST['role_name']) ? trim($_POST['role_name']) : '';
        $permissions = isset($_POST['permissions']) ? $_POST['permissions'] : [];

        if ($role_id <= 0 || empty($role_name)) {
            $error = '请填写完整角色信息！';
        } else {
            try {
                // 检查角色名是否已被其他角色使用
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_roles WHERE role_name = ? AND id != ?");
                $stmt->execute([$role_name, $role_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '角色名称已被其他角色使用！';
                } else {
                    // 权限处理
                    $permissions_json = json_encode(process_permissions($permissions));

                    // 更新角色
                    $stmt = $pdo->prepare("UPDATE sys_roles SET role_name = ?, permissions = ? WHERE id = ?");
                    $result = $stmt->execute([$role_name, $permissions_json, $role_id]);

                    if ($result) {
                        record_log("编辑角色：{$role_name}");
                        $success = '角色更新成功！';
                    } else {
                        $error = '角色更新失败！';
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
    // 删除角色
    elseif ($_POST['action'] == 'delete') {
        $role_id = isset($_POST['role_id']) ? intval($_POST['role_id']) : 0;

        if ($role_id <= 0) {
            $error = '无效的角色ID！';
        } elseif ($role_id == 1) {
            $error = '系统管理员角色不能删除！';
        } else {
            try {
                // 检查是否有用户使用此角色
                $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM sys_users WHERE role_id = ?");
                $stmt->execute([$role_id]);
                $result = $stmt->fetch();

                if ($result['count'] > 0) {
                    $error = '此角色下有用户，不能删除！';
                } else {
                    // 获取角色名，用于日志记录
                    $stmt = $pdo->prepare("SELECT role_name FROM sys_roles WHERE id = ?");
                    $stmt->execute([$role_id]);
                    $role = $stmt->fetch();

                    if (!$role) {
                        $error = '角色不存在！';
                    } else {
                        // 删除角色
                        $stmt = $pdo->prepare("DELETE FROM sys_roles WHERE id = ?");
                        $result = $stmt->execute([$role_id]);

                        if ($result) {
                            record_log("删除角色：{$role['role_name']}");
                            $success = '角色删除成功！';
                        } else {
                            $error = '角色删除失败！';
                        }
                    }
                }
            } catch (PDOException $e) {
                $error = '系统错误：' . $e->getMessage();
            }
        }
    }
}

// 处理权限数据结构
function process_permissions($permissions)
{
    $result = [];

    // 如果有all权限，直接返回
    if (isset($permissions['all'])) {
        $result['all'] = true;
        return $result;
    }

    // 处理一级权限
    foreach ($permissions as $key => $value) {
        // 键名中包含点号的是子权限
        if (strpos($key, '.') !== false) {
            list($parent, $child) = explode('.', $key);

            // 初始化父权限数组（如果还没有）
            if (!isset($result[$parent]) || !is_array($result[$parent])) {
                $result[$parent] = [];
            }

            // 设置子权限
            $result[$parent][$child] = true;
        } else {
            // 设置父权限
            $result[$key] = true;
        }
    }

    return $result;
}

// 获取所有角色
try {
    $stmt = $pdo->query("SELECT * FROM sys_roles ORDER BY id");
    $roles = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = '获取角色列表失败：' . $e->getMessage();
    $roles = [];
}

// 权限列表
$permission_list = [
    'system' => '系统设置',
    'system.view' => '查看系统设置',
    'system.user' => '用户管理',
    'system.role' => '角色管理',
    'system.log' => '日志管理',
    'system.backup' => '数据备份',

    'store' => '门店管理',
    'store.view' => '查看门店',
    'store.add' => '添加门店',
    'store.edit' => '编辑门店',
    'store.delete' => '删除门店',
    'store.sync' => '数据同步',

    'employee' => '员工管理',
    'employee.view' => '查看员工',
    'employee.add' => '添加员工',
    'employee.edit' => '编辑员工',
    'employee.delete' => '删除员工',
    'employee.attendance' => '考勤管理',
    'employee.schedule' => '排班管理',
    'employee.performance' => '绩效统计',

    'equipment' => '设备管理',
    'equipment.view' => '查看设备',
    'equipment.add' => '添加设备',
    'equipment.edit' => '编辑设备',
    'equipment.delete' => '删除设备',
    'equipment.maintenance' => '维护记录',
    'equipment.reminder' => '维护提醒',

    'order' => '订单管理',
    'order.view' => '查看订单',
    'order.add' => '添加订单',
    'order.edit' => '编辑订单',
    'order.delete' => '删除订单',
    'order.process' => '订单处理',
    'order.takeaway' => '外带管理',
    'order.delivery' => '外卖管理',
    'order.payment' => '支付管理',
    'order.invoice' => '发票管理',

    'product' => '产品管理',
    'product.view' => '查看产品',
    'product.add' => '添加产品',
    'product.edit' => '编辑产品',
    'product.delete' => '删除产品',
    'product.category' => '分类管理',
    'product.price' => '价格管理',

    'inventory' => '库存管理',
    'inventory.view' => '查看库存',
    'inventory.add' => '入库管理',
    'inventory.out' => '出库管理',
    'inventory.check' => '库存盘点',
    'inventory.alert' => '库存报警',
    'inventory.waste' => '报废管理',

    'supplier' => '供应商管理',
    'supplier.view' => '查看供应商',
    'supplier.add' => '添加供应商',
    'supplier.edit' => '编辑供应商',
    'supplier.delete' => '删除供应商',
    'supplier.price' => '报价记录',

    'purchase' => '采购管理',
    'purchase.view' => '查看采购',
    'purchase.add' => '添加采购',
    'purchase.edit' => '编辑采购',
    'purchase.delete' => '删除采购',
    'purchase.approve' => '采购审核',
    'purchase.verify' => '验收入库',

    'member' => '会员管理',
    'member.view' => '查看会员',
    'member.add' => '添加会员',
    'member.edit' => '编辑会员',
    'member.delete' => '删除会员',
    'member.level' => '等级设置',
    'member.points' => '积分管理',
    'member.card' => '储值卡管理',

    'marketing' => '营销管理',
    'marketing.view' => '查看营销',
    'marketing.activity' => '活动管理',
    'marketing.coupon' => '优惠券管理',
    'marketing.discount' => '折扣管理',
    'marketing.sms' => '短信营销',
    'marketing.wechat' => '微信营销',

    'finance' => '财务管理',
    'finance.view' => '查看财务',
    'finance.daily' => '日结算',
    'finance.income' => '收入管理',
    'finance.expense' => '支出管理',
    'finance.salary' => '工资管理',
    'finance.statement' => '对账单',

    'report' => '数据报表',
    'report.view' => '查看报表',
    'report.sales' => '销售报表',
    'report.store' => '门店报表',
    'report.product' => '产品报表',
    'report.member' => '会员报表',
    'report.finance' => '财务报表',

    'statistics' => '数据分析',
    'statistics.view' => '查看数据',
    'statistics.sales' => '销售分析',
    'statistics.customer' => '顾客分析',
    'statistics.inventory' => '库存分析',
    'statistics.kpi' => 'KPI统计',

    'profile' => '个人信息',
    'profile.view' => '查看个人信息',
    'profile.edit' => '编辑个人信息',

    'all' => '所有权限'
];

// 分组权限，便于前端展示
$permission_groups = [
    '系统设置' => ['system', 'system.view', 'system.user', 'system.role', 'system.log', 'system.backup'],
    '门店管理' => ['store', 'store.view', 'store.add', 'store.edit', 'store.delete', 'store.sync'],
    '员工管理' => ['employee', 'employee.view', 'employee.add', 'employee.edit', 'employee.delete', 'employee.attendance', 'employee.schedule', 'employee.performance'],
    '设备管理' => ['equipment', 'equipment.view', 'equipment.add', 'equipment.edit', 'equipment.delete', 'equipment.maintenance', 'equipment.reminder'],
    '订单管理' => ['order', 'order.view', 'order.add', 'order.edit', 'order.delete', 'order.process', 'order.takeaway', 'order.delivery', 'order.payment', 'order.invoice'],
    '产品管理' => ['product', 'product.view', 'product.add', 'product.edit', 'product.delete', 'product.category', 'product.price'],
    '库存管理' => ['inventory', 'inventory.view', 'inventory.add', 'inventory.out', 'inventory.check', 'inventory.alert', 'inventory.waste'],
    '供应商管理' => ['supplier', 'supplier.view', 'supplier.add', 'supplier.edit', 'supplier.delete', 'supplier.price'],
    '采购管理' => ['purchase', 'purchase.view', 'purchase.add', 'purchase.edit', 'purchase.delete', 'purchase.approve', 'purchase.verify'],
    '会员管理' => ['member', 'member.view', 'member.add', 'member.edit', 'member.delete', 'member.level', 'member.points', 'member.card'],
    '营销管理' => ['marketing', 'marketing.view', 'marketing.activity', 'marketing.coupon', 'marketing.discount', 'marketing.sms', 'marketing.wechat'],
    '财务管理' => ['finance', 'finance.view', 'finance.daily', 'finance.income', 'finance.expense', 'finance.salary', 'finance.statement'],
    '数据报表' => ['report', 'report.view', 'report.sales', 'report.store', 'report.product', 'report.member', 'report.finance'],
    '数据分析' => ['statistics', 'statistics.view', 'statistics.sales', 'statistics.customer', 'statistics.inventory', 'statistics.kpi'],
    '个人信息' => ['profile', 'profile.view', 'profile.edit'],
    '特殊权限' => ['all']
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>角色权限管理</h2>
            <div class="breadcrumb">
                <a href="index.php">系统设置</a> &gt; 角色权限管理
            </div>
        </div>

        <div class="content">
            <?php if (isset($error)): ?>
                <div class="alert alert-danger"><?php echo $error; ?></div>
            <?php endif; ?>

            <?php if (isset($success)): ?>
                <div class="alert alert-success"><?php echo $success; ?></div>
            <?php endif; ?>

            <div class="action-bar">
                <button class="btn btn-primary" onclick="showAddForm()">添加角色</button>
            </div>

            <!-- 添加角色表单 -->
            <div id="addRoleForm" class="form-container" style="display: none;">
                <h3>添加角色</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="add">

                    <div class="form-group">
                        <label for="role_name">角色名称：</label>
                        <input type="text" id="role_name" name="role_name" required>
                    </div>

                    <div class="form-group">
                        <label>权限设置：</label>
                        <div class="options-container">
                            <?php foreach ($permission_groups as $group => $permissions): ?>
                                <div class="option-group">
                                    <h4 class="group-header"><?php echo $group; ?></h4>
                                    <?php foreach ($permissions as $permission): ?>
                                        <div class="checkbox-item">
                                            <label>
                                                <input type="checkbox" name="permissions[<?php echo $permission; ?>]" value="1" <?php echo $permission == 'all' ? 'onclick="toggleAllPermissions(this)"' : ''; ?>>
                                                <?php echo $permission_list[$permission]; ?>
                                            </label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideAddForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 编辑角色表单 -->
            <div id="editRoleForm" class="form-container" style="display: none;">
                <h3>编辑角色</h3>
                <form method="post" action="">
                    <input type="hidden" name="action" value="edit">
                    <input type="hidden" name="role_id" id="edit_role_id">

                    <div class="form-group">
                        <label for="edit_role_name">角色名称：</label>
                        <input type="text" id="edit_role_name" name="role_name" required>
                    </div>

                    <div class="form-group">
                        <label>权限设置：</label>
                        <div class="options-container" id="edit_permissions_container">
                            <?php foreach ($permission_groups as $group => $permissions): ?>
                                <div class="option-group">
                                    <h4 class="group-header"><?php echo $group; ?></h4>
                                    <?php foreach ($permissions as $permission): ?>
                                        <div class="checkbox-item">
                                            <label>
                                                <input type="checkbox" name="permissions[<?php echo $permission; ?>]" value="1" id="edit_perm_<?php echo str_replace('.', '_', $permission); ?>" <?php echo $permission == 'all' ? 'onclick="toggleAllPermissionsEdit(this)"' : ''; ?>>
                                                <?php echo $permission_list[$permission]; ?>
                                            </label>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>

                    <div class="form-actions">
                        <button type="submit" class="btn btn-success">保存</button>
                        <button type="button" class="btn btn-secondary" onclick="hideEditForm()">取消</button>
                    </div>
                </form>
            </div>

            <!-- 角色列表 -->
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>角色名称</th>
                            <th>权限数量</th>
                            <th>创建时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($roles)): ?>
                            <tr>
                                <td colspan="5" class="text-center">暂无角色数据</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($roles as $role): ?>
                                <?php
                                $permissions = !empty($role['permissions']) ? json_decode($role['permissions'], true) : [];
                                $permissionCount = 0;

                                if (!empty($permissions)) {
                                    if (isset($permissions['all']) && $permissions['all'] === true) {
                                        $permissionCount = '全部权限';
                                    } else {
                                        // 计算权限数量
                                        foreach ($permissions as $key => $value) {
                                            if (is_array($value)) {
                                                $permissionCount += count($value);
                                            } else {
                                                $permissionCount++;
                                            }
                                        }
                                    }
                                }
                                ?>
                                <tr>
                                    <td><?php echo $role['id']; ?></td>
                                    <td><?php echo htmlspecialchars($role['role_name']); ?></td>
                                    <td><?php echo $permissionCount; ?></td>
                                    <td><?php echo $role['create_time']; ?></td>
                                    <td>
                                        <button class="btn btn-sm btn-edit" onclick="editRole(<?php echo $role['id']; ?>, '<?php echo htmlspecialchars($role['role_name']); ?>', <?php echo htmlspecialchars(json_encode($permissions)); ?>)">编辑</button>
                                        <?php if ($role['id'] != 1): // 防止删除超级管理员角色 
                                        ?>
                                            <button class="btn btn-sm btn-delete" onclick="deleteRole(<?php echo $role['id']; ?>, '<?php echo htmlspecialchars($role['role_name']); ?>')">删除</button>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 删除角色表单 -->
            <form id="deleteRoleForm" method="post" action="" style="display: none;">
                <input type="hidden" name="action" value="delete">
                <input type="hidden" name="role_id" id="delete_role_id">
            </form>
        </div>
    </div>

    <script>
        // 显示添加角色表单
        function showAddForm() {
            document.getElementById('addRoleForm').style.display = 'block';
        }

        // 隐藏添加角色表单
        function hideAddForm() {
            document.getElementById('addRoleForm').style.display = 'none';
        }

        // 显示编辑角色表单
        function editRole(id, roleName, permissions) {
            document.getElementById('edit_role_id').value = id;
            document.getElementById('edit_role_name').value = roleName;

            // 重置所有权限
            var checkboxes = document.querySelectorAll('#edit_permissions_container input[type="checkbox"]');
            checkboxes.forEach(function(checkbox) {
                checkbox.checked = false;
            });

            // 设置已有权限
            if (permissions) {
                // 处理all权限
                if (permissions.all) {
                    document.getElementById('edit_perm_all').checked = true;
                    // 选中所有权限
                    checkboxes.forEach(function(checkbox) {
                        checkbox.checked = true;
                    });
                } else {
                    // 处理一级权限
                    for (var key in permissions) {
                        if (permissions.hasOwnProperty(key)) {
                            var value = permissions[key];

                            if (typeof value === 'boolean' && value) {
                                var checkbox = document.getElementById('edit_perm_' + key);
                                if (checkbox) {
                                    checkbox.checked = true;
                                }
                            } else if (typeof value === 'object') {
                                // 处理二级权限
                                for (var subKey in value) {
                                    if (value.hasOwnProperty(subKey) && value[subKey]) {
                                        var checkbox = document.getElementById('edit_perm_' + key + '_' + subKey);
                                        if (checkbox) {
                                            checkbox.checked = true;
                                        }
                                    }
                                }
                            }
                        }
                    }
                }
            }

            document.getElementById('editRoleForm').style.display = 'block';
        }

        // 隐藏编辑角色表单
        function hideEditForm() {
            document.getElementById('editRoleForm').style.display = 'none';
        }

        // 删除角色确认
        function deleteRole(id, roleName) {
            if (confirm('确定要删除角色 "' + roleName + '" 吗？')) {
                document.getElementById('delete_role_id').value = id;
                document.getElementById('deleteRoleForm').submit();
            }
        }

        // 选中"所有权限"时，自动选中所有权限
        function toggleAllPermissions(checkbox) {
            var checkboxes = document.querySelectorAll('#addRoleForm input[type="checkbox"]');
            checkboxes.forEach(function(item) {
                item.checked = checkbox.checked;
            });
        }

        // 编辑表单中的全选功能
        function toggleAllPermissionsEdit(checkbox) {
            var checkboxes = document.querySelectorAll('#editRoleForm input[type="checkbox"]');
            checkboxes.forEach(function(item) {
                item.checked = checkbox.checked;
            });
        }
    </script>
</body>

</html>